/*
The following code is

© Andreas Amann, 2007-2011
http://andreasamann.com/

You may incorporate this code into your program(s) without restriction.
This code has been provided "AS IS" and the responsibility for its operation is yours.
You are not permitted to redistribute this code under my name after having made changes.
If you're going to redistribute the code, please make it clear that the code was descended
from my code, but that you've made changes.
*/

// main scoreboard class (all sports)
SF_._scoreBoard = function(theSport)
{
	this.reloadInterval = function(){return 60000;} // reload-interval while games are ongoing (might be overwritten in this.intialize())
	this.clear();
	this.initialize(theSport);
}

SF_._scoreBoard.prototype.clear = function()
{
	this.dates = null;
	this.nextReload = null;
	this.xmlRequest = null;
	this.xmlPlaysRequest = null;
	this.scoreBoardLink = null;
	this.gameUpdate = null;
	this.highlightTimer = null;
	this.highlightIteration = 0;
	this.reloadTimer = null;
	this.popupTimer = null;
	this.currentGameStats = null;
	this.isCurrentDay = false;
	this.gameSortOrder = [];
	this.gameDates = [];
	this.theDateString = "";
	this.firstLiveGame = null;
}

SF_._scoreBoard.prototype.gameTimeCompare = function(game1, game2)
{
	return game1.gameTime - game2.gameTime;
}

SF_._scoreBoard.prototype.gameDateCompare = function(date1, date2)
{
	return new Date(date1.date).getTime() - new Date(date2.date).getTime();
}

SF_._scoreBoard.prototype.updateTitleMenu = function()
{
	var theDate = new Date(this.theDateString.substr(0,4),parseInt(this.theDateString.substr(4,2),10)-1,this.theDateString.substr(6,2));
	var theDateString = this.theDateString.replace(/[^0-9]/g,"");
	var pagingLinks = [null,null];
	if (this.gameDates && this.gameDates.length)
	{
		if ((this.gameDates[0] + "").replace(/[^0-9]/g,"") < theDateString)
		{
			pagingLinks[0] = this.gameDates[0];
			for (var i = 1, len = this.gameDates.length; i < len; i++)
			{
				if (this.gameDates[i])
				{
					var theGameDate = (this.gameDates[i] + "").replace(/[^0-9]/g,"");
					pagingLinks[0] = theGameDate < theDateString ? this.gameDates[i] : pagingLinks[0];
					pagingLinks[1] = theGameDate > theDateString ? this.gameDates[i] : pagingLinks[1];
					if (pagingLinks[1])
						i = len;
				}
			}
		}
		else
		{
			if ((this.gameDates[0] + "").replace(/[^0-9]/g,"") > theDateString)
				pagingLinks[1] = this.gameDates[0];
			else
				pagingLinks[1] = this.gameDates[1];
		}
	}
	$("titleMenu").innerHTML = "<span " + (pagingLinks[0] ? "onclick='SF_.theScoreBoard.scoreBoardLink=\"" + pagingLinks[0] + "\";SF_.theScoreBoard.load()';" : "style='visibility:hidden;'") + "> ◀ </span><span onclick='SF_.theScoreBoard.scoreBoardLink=null;SF_.theScoreBoard.load()' id='" + theDateString + "'>" + WC_.weekdayNames[theDate.getDay()] + ", " + WC_.monthNames[theDate.getMonth()] + " " + theDate.getDate() + "</span><span " + (pagingLinks[1] ? "onclick='SF_.theScoreBoard.scoreBoardLink=\"" + pagingLinks[1] + "\";SF_.theScoreBoard.load()';" : "style='visibility:hidden;'") + "> ▶ </span>";
}

SF_._scoreBoard.prototype.load = function()
{
	SF_.ignoreMouseUp = true;
	var temp = SF_.abortOngoingRequests();
	SF_.theStandings.clear();
	$s("titleMenu").visibility = "hidden";
	$("stMenu").innerHTML = "Standings";
	$("sbMenu").innerHTML = "<span class='activeMenu'>Scoreboard</span>";
	WC_.animateSpinner("ReloadSpinner");
	if ($("mainContent").innerText == "Data Unavailable" )
		$("mainContent").innerHTML = "";
	SF_.prefs.currentDisplay = "scoreboard";
	WC_.setInstancePref("currentDisplay", SF_.prefs.currentDisplay);
	var _self = this;
	this.xmlRequest = new XMLHttpRequest();
	this.xmlRequest.onload = function() {_self.parse();}
	this.xmlRequest.open("GET",this.scoreBoardBaseLink() + (this.scoreBoardLink || ""));
	this.xmlRequest.setRequestHeader("Cache-Control", "no-cache");
	this.xmlRequest.setRequestHeader("Cookie", "");
	this.xmlRequest.send(null);
}

SF_._scoreBoard.prototype.draw = function()
{
	var _self = this;
	this.firstLiveGame = null;
	this.dates.sort(this.gameDateCompare);
	for (var iDate = 0; iDate < this.dates.length; iDate++)
	{
		if (!this.dates[iDate].games.length)
			this.dates.splice(iDate--,1);
	}
	if (!this.isCurrentDay)
		this.currentGameStats = null;
	var lastGameStats = new Array();
	this.gameUpdate = new Array();
	this.nextReload = this.nextReload > new Date().getTime() ? this.nextReload : new Date().getTime() + 3600000;
	var scoreTable = "<table id='scoreboard'>";
	var tableCol = 0;
	for (var iDate in this.dates)
	{
		var theDate = this.dates[iDate];
		theDate.games.sort(this.gameTimeCompare);
		if (theDate.date)
		{
			tableCol += 6;
			// add empty rows so we don't get a line all the way across if the last row contained a game with our favorite team
			scoreTable += "<tr></tr><tr class='dateRow' onmouseover='SF_.closePopup();'><td colspan='11'>" + theDate.date + "</td></tr><tr></tr>";
		}
		for (var iGame in theDate.games)
		{
			scoreTable += iGame % 2 == 0 ? ("<tr" + (iGame % 4 != 0 ? " class='odd'>" : ">")) : "<td class='middleCol'></td>";
			var theGame = theDate.games[iGame];
			var hasFav = false;
			if (theGame.hasFav != null)
				hasFav = theGame.hasFav;
			else if (SF_.prefs.favoriteTeam >= 0 && SF_.teams[SF_.prefs.currentLeague][SF_.prefs.favoriteTeam].shortName)
				hasFav = (theGame.awayTeam == SF_.teams[SF_.prefs.currentLeague][SF_.prefs.favoriteTeam].shortName.toUpperCase()) || (theGame.homeTeam == SF_.teams[SF_.prefs.currentLeague][SF_.prefs.favoriteTeam].shortName.toUpperCase());
			var tdString = "<td class='sb game_" + iDate+ "_" + iGame + "' onmouseover=SF_.theScoreBoard.showGameDetails('" + iDate + "_" + iGame + "','" + WC_.sanitizeString(theGame.gameID) + "');" + (theGame.link ? " onmouseup=if(SF_.ignoreMouseUp)return;widget.openURL('" + WC_.sanitizeString(theGame.link) + "');" : "" ) + ">";
			var awayTeamClass = ">";
			var homeTeamClass = ">";
			if (theGame.status == "F")
			{
				if( theGame.awayScore > theGame.homeScore)
					awayTeamClass = " class='w'>";
				else
					homeTeamClass = " class='w'>";
			}
			else
			{
				if (theGame.awayTeamClass)
					awayTeamClass = " class='" + theGame.awayTeamClass + "'>";
				if (theGame.homeTeamClass)
					homeTeamClass = " class='" + theGame.homeTeamClass + "'>";
				if (!this.firstLiveGame)
					this.firstLiveGame = tableCol - 4 * iDate;
			}
			var currentGame = tdString + "<span" + awayTeamClass + WC_.sanitizeString(theGame.awayTeam) + "</span></td>" + tdString + "<span" + homeTeamClass + WC_.sanitizeString(theGame.homeTeam) + "</span></td>";
			tdString = tdString.replace(/sb game_/g,"sbr game_");
			if (theGame.status == "P" || theGame.status == "PP")
				currentGame += tdString.replace(/>/," colspan='3'>");
			else
				currentGame += tdString + theGame.awayScore + tdString + theGame.homeScore + tdString;
			if (theGame.status == "P")
			{
				// make sure not to enter an infinite reload loop if the game data is not updated immediately after the schedules game time
				if (theGame.gameTime > new Date().getTime())
					this.nextReload = Math.min(this.nextReload,theGame.gameTime);
				else
					this.nextReload = new Date().getTime() + this.reloadInterval();
			}
			else if (theGame.status == "")
				this.nextReload = new Date().getTime() + this.reloadInterval();
			currentGame += theGame.scoreDetails + "</td>";
			var gameStatID = theGame.awayTeam + "@" + theGame.homeTeam;
			// make sure we properly deal with double headers…
			while (lastGameStats[gameStatID])
				gameStatID += "_";
			if (this.isCurrentDay)
				lastGameStats[gameStatID] = [theGame.awayScore,theGame.homeScore,theGame.status];
			if (this.currentGameStats && this.currentGameStats[gameStatID])
			{
				if (this.currentGameStats[gameStatID].join("|") != lastGameStats[gameStatID].join("|")
					&& this.currentGameStats[gameStatID][2] == "")
				{
					if (this.currentGameStats[gameStatID][0] < lastGameStats[gameStatID][0])
						this.gameUpdate.push([tableCol,0]);
					if (this.currentGameStats[gameStatID][1] < lastGameStats[gameStatID][1])
						this.gameUpdate.push([tableCol,1]);
					if (lastGameStats[gameStatID][2] == "F")
						this.gameUpdate.push([tableCol,2]);
				}
			}
			if (hasFav)
				currentGame = currentGame.replace(/'(sbr?)([' ])/g,"'$1_fav$2");
			if (theGame.status == "P")
			{
				if (theGame.awayTeamDetails != "")
					currentGame = currentGame.replace(/<td/,"<td title='" + theGame.awayTeamDetails + "'");
				if (theGame.homeTeamDetails != "")
					currentGame = currentGame.replace(/(<td.*?<\/td>)<td/,"$1<td title='" + theGame.homeTeamDetails + "'");
			}
			scoreTable += currentGame;
			tableCol++;
		}
		if (iGame % 2 == 0)
		{
			// finish out the current row with enough cells and add a dummy entry to the gameStats so that we can easily locate a game in the scoreboard table later
			tableCol++;
			scoreTable += "<td width='auto'></td><td colspan='5'> </td>"
		}
		scoreTable += "</tr>";
	}
	if (this.byeWeekTeams)
		scoreTable += "<tr></tr><tr class='byeRow' onmouseover='SF_.closePopup();'><td colspan='11'>Bye: " + this.byeWeekTeams + "</td></tr><tr></tr>";
	// define some default widths and add enough room for double-digits scores to prevent shifting of the scoreboard with every refresh
	scoreTable += "<tr height='1px'><td width='49%' colspan='5'> </td><td></td><td width='49%' colspan='5'> </td></tr></table>";
	$s("standingsFooter").visibility = "";
	$("standingsHeader").innerHTML = "";
	$s("mainContent").top = $s("mainContent").bottom = "";
	if (this.dates.length)
		$("mainContent").innerHTML = scoreTable;
	else
	{
		if (SF_.prefs.currentSport == "Football" && SF_.prefs.currentLeague != "NFL" && this.scoreBoardLink && this.scoreBoardLink.match(/week16/))
			this.customText("Bowl Schedules Not Yet Available");
		else if (SF_.prefs.currentSport == "Football" && SF_.prefs.currentLeague == "NFL" && this.scoreBoardLink && parseInt(this.scoreBoardLink.replace(/.*week(.*)/,"$1"),10) > 17)
			this.customText("Game Schedules Not Yet Available");
		else
			this.customText("No Games Scheduled");
	}
	SF_.closePopup();
	if (this.gameUpdate && this.gameUpdate.length)
	{
		this.highlightIteration = 0;
		this.highlightNewScores();
	}
	this.currentGameStats = lastGameStats;
	this.updateTitleMenu();
	$s("titleMenu").visibility = "";
	SF_.sizeWidget();
	WC_.stopSpinner("ReloadSpinner");
	$s("SportIcon").display = "";
	SF_.ignoreMouseUp = false;
	if (this.isCurrentDay)
		this.reloadTimer = setTimeout(function(){SF_.theScoreBoard.load()},this.nextReload - new Date().getTime());
}

SF_._scoreBoard.prototype.customText = function(theText)
{
	this.xmlRequest = null;
	$("mainContent").innerHTML = "<div style='font-style:italic;vertical-align:center;padding-top:" + (((SF_.prefs.currentLeague in {"NCAAB":'',"FBS":''} && SF_.prefs.currentDisplay == "scoreboard") ? 1.2 : 1) * parseFloat(this.customTextOffset)) + "em" + ";'>" + theText + "</div>";
	$s("mainContent").cssText = "";
	$("standingsHeader").innerHTML = "";
	$s("standingsFooter").visibility = "";
	$s("ContentScrollbar").visibility = "";
	$s("SportIcon").display = "";
	SF_.sizeWidget();
	WC_.stopSpinner("ReloadSpinner");
	SF_.ignoreMouseUp = false;
	var _self = SF_.prefs.currentDisplay == "scoreboard" ? SF_.theScoreBoard : SF_.theStandings;
	_self.nextReload = new Date().getTime() + 900000;
	if (!(SF_.prefs.currentDisplay == "scoreboard" && !SF_.theScoreBoard.isCurrentDay))
		_self.reloadTimer = setTimeout(function(){_self.load()},_self.nextReload - new Date().getTime());
}

SF_._scoreBoard.prototype.highlightNewScores = function()
{
	for (var i in this.gameUpdate)
	{
		var theGameUpdate = this.gameUpdate[i];
		this.getScoreBoardCell(theGameUpdate[0], theGameUpdate[1] + 2).innerHTML = (this.highlightIteration % 2 != 0) ? this.getScoreBoardCell(theGameUpdate[0], theGameUpdate[1] + 2).innerText : ("<span class='w'>" + this.getScoreBoardCell(theGameUpdate[0], theGameUpdate[1] + 2).innerText + "</span>");
	}
	if (this.highlightIteration < 7)
	{
		this.highlightIteration++;
		var _self = this;
		this.highlightTimer = setTimeout(function(){_self.highlightNewScores()}, 1000);
	}
	else
	{
		this.gameUpdate = [];
		this.highlightTimer = null;
	}
}

SF_._scoreBoard.prototype.cancelScoreUpdates = function()
{
	if (this.highlightTimer != null)
	{
		clearTimeout(this.highlightTimer);
		this.highlightTimer = null;
		if (this.gameUpdate)
		{
			this.highlightIteration = 7;
			this.highlightNewScores();
		}
	}
}

SF_._scoreBoard.prototype.getScoreBoardCell = function(iGame,iOffset)
{
	var theNodes = $("mainContent").childNodes[0].childNodes[0].childNodes;
	return theNodes[parseInt(iGame/2,10)].childNodes[(iGame % 2 == 0 ? 0 : (theNodes[parseInt(iGame/2,10)].childNodes.length > 9 ? 6 : 4)) + iOffset];
}

SF_._scoreBoard.prototype.showGameDetails = function(iGame,GameID)
{
	var _self = this;
	if (!SF_.prefs.showGameDetails) return;
	if (!this.dates) return;
	if (this.dates[iGame.split("_")[0]].games[iGame.split("_")[1]].gameDetails == null) return;
	if ($s("gameDetails").visibility == "visible" && GameID == SF_.currentPopup) return;
	if ($s("ReloadSpinner").visibility == "visible") return;
	WC_.stopSpinner("ReloadSpinner");
	$s("scoreDetails").width = "";
	$s("gameDetails").width = "";
	$s("gameDetails").width = ((SF_.prefs.useLargeFonts ? 1.2 : 1) * parseInt(document.defaultView.getComputedStyle($("gameDetails")).getPropertyValue("width"),10)) + "px";
	if (this.popupTimer != null)
		clearTimeout(this.popupTimer);
	// close current game popup, remove old highlight from scoreboard and highlight the game we will be loading the popup for
	$("mainContent").innerHTML = $("mainContent").innerHTML.replace(/ selected/g,"").replace(new RegExp("(game_" + iGame + ")","g"),"$1 selected");	
	WC_.refreshView();
	SF_.currentPopup = GameID;
	if (this.xmlRequest)
	{
		this.xmlRequest.abort();
		this.xmlRequest = null;
	}
	$("scoreDetails").innerHTML = this.dates[iGame.split("_")[0]].games[iGame.split("_")[1]].gameDetails;
	$s("gameDetails").opacity = 0;
	if (SF_.fadeAnimation) SF_.fadeAnimation.stop();
	SF_.fadeAnimation = new AppleAnimator(500, 13, 0, 1, SF_.fadePopup);
	SF_.fadeAnimation.oncomplete = WC_.refreshView;
	SF_.fadeAnimation.start();
	$s("gameDetails").visibility = "visible";
	$s("gameDetails").right = (iGame.split("_")[1] % 2 != 0) ? "" : "11px";	// 11px needed for the shadow (offset + blur)
	$s("gameDetails").left = (iGame.split("_")[1] % 2 != 0) ? "11px" : "";		// …so we make this symmetrical
	$s("gameDetails").height = ($("scoreDetails").offsetHeight +  5) + "px";
	$s("gameDetails").width = ($("scoreDetails").scrollWidth + 10) + "px";
	$s("gameDetails").height = ($("scoreDetails").offsetHeight +  5) + "px";
	WC_.refreshView();
	setTimeout("$('gameDetails').onmouseover = function() {SF_.closePopup();}",100);
	this.popupTimer = setTimeout(function(){SF_.closePopup(_self)},20000)
}

SF_._scoreBoard.prototype.timeString = function(gameTime)
{
	gameTime = new Date(gameTime);
	return (gameTime.getHours() == 0 ? 12 : (gameTime.getHours() > 12 ? gameTime.getHours() - 12 : gameTime.getHours())) + ":" + WC_.twoDigNum(gameTime.getMinutes()) + " " + (gameTime.getHours() < 12 ? "A" : "P") + "M";
}

SF_._scoreBoard.prototype.dateFromString = function()
{
	return new Date(parseInt(this.theDateString.substr(0,4),10),parseInt(this.theDateString.substr(4,2),10)-1,parseInt(this.theDateString.substr(6,2),10));
}

SF_._scoreBoard.prototype.isDST = function(theDate)
{
	theDate = theDate || this.dateFromString();
	// use DST rules for US as of 2008: 2nd Sunday of March through 1st Sunday of November
	var theMonth = theDate.getMonth();
	var theDay = theDate.getDate();
	if (theMonth < 2 || theMonth == 11) // Jan, Feb, Dec
		return false;
	else if (theMonth > 2 && theMonth < 10) // Apr - October
		return true;
	else if (theMonth == 2) // Mar
	{
		if (theDay < 8)
			return false;
		else
			return ((theDay - 7) > theDate.getDay());
	}
	else if (theMonth == 10) // Nov
	{
		if (theDay > 6)
			return false;
		else
			return (theDay < theDate.getDay());
	}
}

SF_._scoreBoard.prototype.buildLineScoreTable = function(lineScoreDetails)
{
	var lineScore = "<table><tr class='header'><td class='alignleft'>" + lineScoreDetails.titleText + "</td><td class='summary'";
	for (var i in lineScoreDetails.title)
		lineScore += ">" + lineScoreDetails.title[i] + "</td><td";
	lineScore += " class='summary'>T</td></tr>";
	lineScore += "<tr class='odd'><td class='alignleft' nowrap>" + lineScoreDetails.awayTeam + (lineScoreDetails.possession == "away" ? " <sub><img width=12px height=12px src='Images/Icons/" + SF_.prefs.currentSport + ".png' /></sub>" : "") + "</td>";
	for (var i = 0, len = lineScoreDetails.awayScores.length - 1; i < len; i++)
		lineScore += "<td" + (i ? "" : " class='summary'") + ">" + (lineScoreDetails.awayScores[i] == null ? "" : (parseInt(lineScoreDetails.awayScores[i]) ? lineScoreDetails.awayScores[i] : "<span class='zero'>" + lineScoreDetails.awayScores[i] + "</span>")) + "</td>"
	lineScore += "<td class='summary'>" + lineScoreDetails.awayScores[lineScoreDetails.awayScores.length - 1] + "</td></tr>";
	lineScore += "<tr class='odd'><td class='alignleft' nowrap>" + lineScoreDetails.homeTeam + (lineScoreDetails.possession == "home" ? " <sub><img width=12px height=12px src='Images/Icons/" + SF_.prefs.currentSport + ".png' /></sub>" : "") + "</td>";
	for (var i = 0, len = lineScoreDetails.homeScores.length - 1; i < len; i++)
		lineScore += "<td" + (i ? "" : " class='summary'") + ">" + (lineScoreDetails.homeScores[i] == null ? "" : (parseInt(lineScoreDetails.homeScores[i]) ? lineScoreDetails.homeScores[i] : "<span class='zero'>" + lineScoreDetails.homeScores[i] + "</span>")) + "</td>"
	lineScore += "<td class='summary'>" + lineScoreDetails.homeScores[lineScoreDetails.homeScores.length - 1] + "</td></tr></tr></table>";
	return lineScore;
}

// sports-specific scoreboard setup and functions

SF_._scoreBoard.prototype.initialize = function(theSport)
{
	switch (theSport)
	{
		case "MLB":
			this.dayOffset = 0;
			this.customTextOffset = "4.2em";
			this.scoreBoardBaseLink = function(){
				if (!this.scoreBoardLink)
					this.scoreBoardLink = this._MLB_getDateString() + "/miniscoreboard.xml";
				else
					this.scoreBoardLink += this.scoreBoardLink.match(/miniscoreboard.xml/) ? "" : "/miniscoreboard.xml";
				return "http://gdx.mlb.com/components/game/" + SF_.prefs.currentLeague.toLowerCase() + "/";
			}
			this.parse = this.parse_MLB;
			this.showGameDetails = this.showGameDetails_MLB;
			break;
		case "NBA":
			this.customTextOffset = "4.7em";
			this.scoreboardMainLink = "";
			this.reloadInterval = function(){return SF_.prefs.currentLeague.match(/NBA/) ? 20000 : 60000;}
			this.scoreBoardBaseLink = function(){
				if (SF_.prefs.currentLeague == "NBA")
					return "http://www.nba.com/scores/fullScoreboard.jsp" + (this.scoreBoardLink ? "?date=" : "?date=" + this._NBA_getDateString());
				else if (SF_.prefs.currentLeague == "WNBA")
					return "http://www.wnba.com/scores/fullScoreboardWNBA.jsp" + (this.scoreBoardLink ? "?date=" : "?date=" + this._NBA_getDateString());
				else
					return "http://www.cbssports.com/collegebasketball/scoreboard/" + this.scoreboardMainLink;
			}
			this.parse = this.parse_NBA;
			break;
		case "NFL":
			this.byeWeekTeams = null;
			this.customTextOffset = "6.2em";
			this.scoreBoardBaseLink = function(){
				return "http://www.sportsline.com/" + (SF_.prefs.currentLeague == "NFL" ? "nfl" : "collegefootball") + "/scoreboard/";}
			this.parse = this.parse_NFL;
			this.updateTitleMenu = this.updateTitleMenu_NFL;
			break;
		case "NHL":
			this.customTextOffset = "4.1em";
			this.scoreBoardBaseLink = function(){return "http://www.sportsline.com/nhl/scoreboard/";}
			this.parse = this.parse_NHL;
			break;
	}
}

SF_._scoreBoard.prototype.parse_NHL = function()
{
	if (!this.xmlRequest) return;
	if (this.xmlRequest && !this.xmlRequest.responseText)
	// no data available
	{
		this.customText("Data Unavailable");
		return;
	}
	var xmlResponse = this.xmlRequest.responseText;
	this.xmlRequest = null;
	xmlResponse = xmlResponse.replace(/[\n\r]/g,"");
	var NHLatl = {myScoresCurrentDay:null, myScoresUrl:null}
	var theGames = new Array();
	var gameData = xmlResponse.match(/script[^<]*var NHLatl.*?<\/script>/)[0].replace(/.*?var /,"").replace(/,\s*myScoresIcon.*/,"}");
	// don't use "eval(gameData)" to avoid potential XSS vulnerabilities - manually parse and populate the data instead
	NHLatl.myScoresCurrentDay = gameData.replace(/.*?myScoresCurrentDay:.*?'(.*?)'.*/,"$1");
	NHLatl.myScoresUrl = gameData.replace(/.*?myScoresUrl:.*?'(.*?)'.*/,"$1");
	var pagingLinks = xmlResponse.match(/<a +class="?opt(sel)?[ "]+href=.*?\/scoreboard\/[0-9]+(\/preseason)?/g); //"
	this.theDateString = NHLatl.myScoresCurrentDay;
	if (pagingLinks)
	{
		if (pagingLinks.length == 3)
			this.theDateString = pagingLinks[1].replace(/.*?([0-9]+).*/,"$1");
		else
		{
			if (pagingLinks.length == 2)
			{
				if (pagingLinks[1].replace(/.*?([0-9]+).*/,"$1") <= this.theDateString)
					this.theDateString = pagingLinks[1].replace(/.*?([0-9]+).*/,"$1");
				else if (pagingLinks[0].replace(/.*?([0-9]+).*/,"$1") >= this.theDateString)
					this.theDateString = pagingLinks[0].replace(/.*?([0-9]+).*/,"$1");
			}
		}
	}
	var theDate = this.dateFromString();
	this.gameDates = [pagingLinks && pagingLinks[0].replace(/.*scoreboard\//,"") < this.theDateString ? WC_.sanitizeString(pagingLinks[0].replace(/.*scoreboard\//,"")) : null,pagingLinks && pagingLinks[pagingLinks.length-1].replace(/.*scoreboard\//,"") > this.theDateString ? WC_.sanitizeString(pagingLinks[pagingLinks.length-1].replace(/.*scoreboard\//,"")) : null];
	gameData = gameData.match(/games.*?{(.*?)}}/) ? gameData.replace(/.*?games.*?{(.*?)}}.*/,"$1}").match(/[0-9]+[^:}]*:[^{]*{.*?asog/g) : [];
	var star_players = [];
	for (var i in gameData)
	{
		var theGame = gameData[i];
		if (theGame.match(/star_players/))
		{
			var starPlayers = theGame.replace(/.*?star_players.*?\[(.*?)\].*/,"$1").match(/{.*?}/g) || [];
			star_players = [];
			for (var j in starPlayers)
			{
				var thePlayer = starPlayers[j];
				star_players.push({
					stars: thePlayer.replace(/.*?stars[^:]*:\s*([0-9]+).*/,"$1"),
					numGoals: thePlayer.replace(/.*?numGoals[^:]*:.*?([0-9]+).*/,"$1"),
					numAssists: thePlayer.replace(/.*?numAssists[^:]*:.*?([0-9]+).*/,"$1"),
					saves: thePlayer.replace(/.*?saves[^:]*:.*?([0-9]+).*/,"$1"),
					position: thePlayer.replace(/.*?position[^:]*:\s*"(.*?)".*/,"$1"),
					teamAbbr: thePlayer.replace(/.*?teamAbbr[^:]*:\s*"(.*?)".*/,"$1"),
					savePct: thePlayer.replace(/.*?savePct[^:]*:\s*"(.*?)".*/,"$1"),
					firstName: thePlayer.replace(/.*?firstName[^:]*:\s*"(.*?)".*/,"$1"),
					lastName: thePlayer.replace(/.*?lastName[^:]*:\s*"(.*?)".*/,"$1")
				});
			}
		}
		theGames.push({
			game_abbr: theGame.replace(/.*?game_abbr[^:]*:.*?"(.*?)".*/,"$1"),
			schedule_time: theGame.replace(/.*?schedule_time[^:]*:.*?([0-9]+).*/,"$1"),
			game_status: theGame.replace(/.*?game_status[^:]*:.*?"(.*?)".*/,"$1"),
			game_period: parseInt(theGame.replace(/.*?game_period[^:]*:.*?([0-9]+).*/,"$1")),
			time_remaining: theGame.replace(/.*?time_remaining[^:]*:.*?"(.*?)".*/,"$1"),
			gamecenter_flag: theGame.replace(/.*?gamecenter_flag[^:]*:[\s"]*(true|false).*/,"$1") == "true", //"
			recap_flag: theGame.replace(/.*?recap_flag[^:]*:[\s"]*(true|false).*/,"$1") == "true", //"
			long_game_text: theGame.match(/long_game_text/) ? theGame.replace(/.*?long_game_text[^:]*:.*?"(.*?)".*/,"$1").replace(/\\/,"") : null,
			last_scoring_play: theGame.match(/last_scoring_play/) ? theGame.replace(/.*?last_scoring_play[^:]*:.*?"(.*?)".*/,"$1").replace(/\\/,"") : null,
			aabbrv: theGame.replace(/.*?aabbrv[^:]*:.*?"(.*?)".*/,"$1"),
			anickname: theGame.replace(/.*?anickname[^:]*:.*?"(.*?)".*/,"$1"),
			arecord: theGame.replace(/.*?arecord[^:]*:.*?"(.*?)".*/,"$1"),
			ascore: theGame.replace(/.*?ascore[^:]*:.*?([0-9]+).*/,"$1"),
			astrength: theGame.match(/astrength/) ? gameData[i].replace(/.*?astrength[^:]*:.*?"(.*?)".*/,"$1") : null,
			ashootout_goals: theGame.match(/ashootout_goals/) ? parseInt(theGame.replace(/.*?ashootout_goals[^_:]*:.*?([0-9]+).*/,"$1"),10) : null,
			aline_score: theGame.replace(/.*?aline_score[^:]*:\s*\[(.*?)\].*/,"$1").replace(/\s/g,"").split(","),
			habbrv: theGame.replace(/.*?habbrv[^:]*:.*?"(.*?)".*/,"$1"),
			hnickname: theGame.replace(/.*?hnickname[^:]*:.*?"(.*?)".*/,"$1"),
			hrecord: theGame.replace(/.*?hrecord[^:]*:.*?"(.*?)".*/,"$1"),
			hscore: theGame.replace(/.*?hscore[^:]*:.*?([0-9]+).*/,"$1"),
			hstrength: theGame.match(/hstrength/) ? theGame.replace(/.*?hstrength[^:]*:.*?"(.*?)".*/,"$1") : null,
			hshootout_goals: theGame.match(/hshootout_goals/) ? parseInt(theGame.replace(/.*?hshootout_goals[^_:]*:.*?([0-9]+).*/,"$1"),10) : null,
			hline_score: theGame.replace(/.*?hline_score[^:]*:\s*\[(.*?)\].*/,"$1").replace(/\s/g,"").split(","),
			star_players: star_players
		});
	}
	if (!theGames.length)
	// JavaScript array not yet populated (future date) - assemble required values from the HTML table
	{
		var theGameTable = xmlResponse.match(/<div[^>]*class="scoreBox.*?>.*?<\/div>.*?<\/div>/g);	//"
		if (theGameTable)
		{
			for (var i in theGameTable)
			{
				var theGame = theGameTable[i];
				var aabbrv;
				var habbrv;
				if (theGame.match(/teams\/page\/[A-Z]+/g) && theGame.match(/teams\/page\/[A-Z]+/g).length > 1)
				{
					aabbrv = theGame.match(/teams\/page\/[A-Z]+/g)[0].replace(/teams\/page\//,"");
					habbrv = theGame.match(/teams\/page\/[A-Z]+/g)[1].replace(/teams\/page\//,"");
				}
				else	// fix for All-Star game
				{
					aabbrv = theGame.match(/<b>[^<]+<\/b>/g)[0].replace(/<.*?>/g,"").replace(/[ae]stern Conference/,"C");
					habbrv = theGame.match(/<b>[^<]+<\/b>/g)[1].replace(/<.*?>/g,"").replace(/[ae]stern Conference/,"C");
				}
				if (theGame.match(/formatTime/))
				// future date
					theGames.push({
						game_status: "S",
						schedule_time: theGame.replace(/.*formatTime.*?,\s+([0-9]+).*/,"$1"),
						aabbrv: aabbrv,
						habbrv: habbrv,
						anickname: theGame.match(/<b>.*?<\/b>/g)[1].replace(/<.*?>/g,""),
						hnickname: theGame.match(/<b>.*?<\/b>/g)[2].replace(/<.*?>/g,""),
						game_abbr: aabbrv + "@" + habbrv
						});
					else
					// ongoing or finished (probably pre-season only) - let's populate the minimum required
					{
						theGames.push({
							game_status: theGame.match(/<b>Final<\/b>/) ? "F" : "",
							game_abbr: aabbrv + "@" + habbrv,
							schedule_time: parseInt(i),
							game_period: parseInt(theGame.replace(/.*?<b>[0-9:]* in ([123]).*/,"$1")) ? parseInt(theGame.replace(/.*?<b>[0-9:]* in ([123]).*/,"$1")) + (theGame.match(/<b>[0-9:]* in [0-9]+OT</) ? 3 : 0) : theGame.match(/<tr.*?<\/tr>/g)[1].replace(/.*?<\/td>(.*)<\/td><td.*/,"$1").replace(/<td[^>]*>/g,"").split("<\/td>").length,
							time_remaining: theGame.match(/<b>([0-9:]*) in [123]/) ? theGame.replace(/.*?<b>([0-9:]*) in [123].*/,"$1") : "",
							gamecenter_flag: false,
							recap_flag: false,
							long_game_text: null,
							last_scoring_play: null,
							aabbrv: aabbrv,
							anickname: theGame.match(/<b>.*?<\/b>/g)[2].replace(/<.*?>/g,""),
							arecord: null,
							ascore: theGame.match(/<b>[0-9]+<\/b><\/td>/g)[0].replace(/.*?([0-9]+).*/,"$1"),
							astrength: null,
							ashootout_goals: 0,
							aline_score: theGame.match(/<tr.*?<\/tr>/g)[1].replace(/.*?<\/td>(.*)<\/td><td.*/,"$1").replace(/<td[^>]*>/g,"").split("<\/td>"),
							habbrv: habbrv,
							hnickname: theGame.match(/<b>.*?<\/b>/g)[4].replace(/<.*?>/g,""),
							hrecord: null,
							hscore: theGame.match(/<b>[0-9]+<\/b><\/td>/g)[1].replace(/.*?([0-9]+).*/,"$1"),
							hstrength: null,
							hshootout_goals: null,
							hline_score: theGame.match(/<tr.*?<\/tr>/g)[2].replace(/.*?<\/td>(.*)<\/td><td.*/,"$1").replace(/<td[^>]*>/g,"").split("<\/td>"),
							star_players: []
						});
					}
			}
		}
	}
	this.dates = [{games:[]}];
	for (var iGame in theGames)
	{
		var theGame = theGames[iGame];
		var scoreDetails = "";
		if (theGame.game_status == "S")
		{
			var gameTime = 1000 * theGame.schedule_time;
			scoreDetails = this.timeString(gameTime);
		}
		else if (theGame.game_status == "F")
		{
			scoreDetails = "Final";
			if (theGame.game_period == 4)
				scoreDetails += "/OT";
			else if (theGame.game_period > 4)
				scoreDetails += theGame.ashootout_goals != null ? "/SO" : "/" + (theGame.game_period - 3) + "OT";
		}
		else
		{
			if (theGame.game_period < 4)
				scoreDetails =  WC_.ordinalNumber(theGame.game_period) + ", " + WC_.sanitizeString(theGame.time_remaining.replace(/^0/,""));
			else if (theGame.game_period == 4)
				scoreDetails = "OT, " + WC_.sanitizeString(theGame.time_remaining.replace(/^0/,""));
			else
				scoreDetails = theGame.ashootout_goals != null ? "Shootout" : (theGame.game_period - 3) + "OT, " + WC_.sanitizeString(theGame.time_remaining.replace(/^0/,""));
		}
		var gameDetails = null;
		if (theGame.game_status != "S")
		{
			var title = ["1","2","3","OT","SO"];
			if ((theGame.game_period > 4) && (theGame.ashootout_goals == null))
			{
				title = title.splice(0,3);
				for (var iOT = 1, lenOT = theGame.game_period - 3; iOT <= lenOT; iOT++)
					title.push(iOT + "OT");
			}
			var lineScore = {
				titleText: "",
				awayTeam: WC_.sanitizeString(theGame.anickname.replace(/ /g," ")),
				homeTeam: WC_.sanitizeString(theGame.hnickname.replace(/ /g," ")),
				title: title,
				awayScores: [],
				homeScores: [],
				possession: null
			}
			if (theGame.game_status != "F")
			{
				if (theGame.game_period < 4)
					lineScore.titleText =  WC_.ordinalNumber(theGame.game_period) + " Period, " + WC_.sanitizeString(theGame.time_remaining.replace(/^0/,""));
				else if (theGame.game_period == 4)
					lineScore.titleText = "OT, " + WC_.sanitizeString(theGame.time_remaining.replace(/^0/,""));
				else
					lineScore.titleText = theGame.ashootout_goals != null ? "Shootout" : (theGame.game_period - 3) + "OT, " + WC_.sanitizeString(theGame.time_remaining.replace(/^0/,""));
				if (theGame.astrength == "Power")
					lineScore.awayTeam = "<span class='powerPlay'>" + lineScore.awayTeam + "</span>";
				else if (theGame.hstrength == "Power")
					lineScore.homeTeam = "<span class='powerPlay'>" + lineScore.homeTeam + "</span>";
			}
			else
			{
				lineScore.titleText = "Final";
				if (theGame.game_period == 4)
					lineScore.titleText += "/OT";
				else if (theGame.game_period > 4)
					lineScore.titleText += theGame.ashootout_goals != null ? "/SO" : "/" + (theGame.game_period - 3) + "OT";
				if (theGame.arecord)
					lineScore.awayTeam += " (" + WC_.sanitizeString(theGame.arecord.replace(/-/g,"&#8209;")) + ")";
				if (theGame.hrecord)
					lineScore.homeTeam += " (" + WC_.sanitizeString(theGame.hrecord.replace(/-/g,"&#8209;")) + ")";
			}
			lineScore.title.splice(Math.max(3,theGame.aline_score.length),5);
			for (var i = 0, len = Math.max(3,theGame.aline_score.length); i < len; i++)
			{
				lineScore.awayScores.push(i < theGame.aline_score.length ? (WC_.sanitizeString(theGame.aline_score[i])) + (i == 4 && theGame.hshootout_goals != null ? "(" + theGame.ashootout_goals + ")" : "") : null);
				lineScore.homeScores.push(i < theGame.aline_score.length ? (WC_.sanitizeString(theGame.hline_score[i])) + (i == 4 && theGame.hshootout_goals != null ? "(" + theGame.hshootout_goals + ")" : "") : null);
			}
			lineScore.awayScores.push(WC_.sanitizeString(theGame.ascore));
			lineScore.homeScores.push(WC_.sanitizeString(theGame.hscore));
			gameDetails = this.buildLineScoreTable(lineScore);
			gameDetails += "<div class='playInfo'>";
			if (theGame.game_status != "F")
			{
				if (theGame.long_game_text)
					gameDetails += "<div class='lastPlay'><em>Last Play:</em><br />" + WC_.sanitizeString(theGame.long_game_text.replace(/<.*?>/g,"")) + "</div>";
				if (theGame.last_scoring_play)
					gameDetails += "<em>Last Goal:</em><br />" + WC_.sanitizeString(theGame.last_scoring_play.replace(/<.*?>/g,""));
			}
			else
			{
				var gStars = theGame.star_players;
				if (gStars && gStars.length)
				{
					gameDetails += "<div class='lastPlay'><em>Three Stars:</em>";
					var starsOrder = [];
					for (var i in gStars)
							starsOrder[gStars[i].stars] = WC_.sanitizeString(gStars[i].stars + ". " + gStars[i].firstName.substr(0,1) + ". " + gStars[i].lastName + " - " + gStars[i].teamAbbr) + "<br />    <em>" + WC_.sanitizeString(((gStars[i].position == "G") ? "Saves: " + gStars[i].saves + ", " + "Save Pct: " + gStars[i].savePct : "Goals: " + gStars[i].numGoals + ", Assists: " + gStars[i].numAssists)) + "</em>";
					gameDetails += starsOrder.join("<br />");
				}
			}
			gameDetails += "</div>";
		}
		this.dates[0].games.push({
			gameID: theGame.game_abbr,
			status: theGame.game_status == "S" ? "P" : (theGame.game_status == "F" ? "F" : ""),
			link: theGame.gamecenter_flag ? "http://www.sportsline.com/nhl/gamecenter/" + (theGame.recap_flag ? "recap/" : "live/") + theGame.game_abbr : null,
			gameTime: 1000 * theGame.schedule_time,
			scoreDetails: scoreDetails,
			awayTeam: theGame.aabbrv,
			awayTeamDetails: theGame.anickname + (theGame.arecord ? " (" + theGame.arecord + ")" : ""),
			awayTeamClass: theGame.astrength == "Power" ? "powerPlay" : "",
			awayScore: parseInt(theGame.ascore || 0, 10),
			homeTeam: theGame.habbrv,
			homeTeamDetails: theGame.hnickname + (theGame.hrecord ? " (" + theGame.hrecord + ")" : ""),
			homeTeamClass: theGame.hstrength == "Power" ? "powerPlay" : "",
			homeScore: parseInt(theGame.hscore || 0, 10),
			gameDetails: gameDetails
		});
	}
	this.isCurrentDay = !this.scoreBoardLink || this.theDateString == NHLatl.myScoresCurrentDay
	this.draw();
}

SF_._scoreBoard.prototype._NBA_loadGameDates = function()
{
		var xmlRequest = new XMLHttpRequest();
		var _self = this;
		xmlRequest.onload = function() {_self._NBA_buildGameDateArray(xmlRequest);}
		if (SF_.prefs.currentLeague == "NBA")
			xmlRequest.open("GET","http://www.nba.com/scores/seasongamedate.jsp");
		else
			xmlRequest.open("GET","http://www.wnba.com/scores/seasongamedateWNBA.jsp");
		xmlRequest.setRequestHeader("Cache-Control", "no-cache");
		xmlRequest.setRequestHeader("Cookie", "");
		xmlRequest.send(null);
}

SF_._scoreBoard.prototype._NBA_buildGameDateArray = function(xmlRequest)
{
	var xmlResponse = xmlRequest.responseText;
	if (!xmlResponse) return;
	xmlResponse = xmlResponse.replace(/.*?=/,"").replace(/&.*/,"").split(",");
	var newDates = new Array();
	for (var i in xmlResponse)
		if (parseInt(xmlResponse[i].split("|")[1],10)) newDates.push(parseInt(xmlResponse[i].split("|")[0],10));
	this.gameDates = newDates;
	// in case the scoreboard has already loaded update the header so we get the paging arrows
	if ($("titleMenu").innerHTML.match(/id=.[0-9]+/))
		this.updateTitleMenu();
}

SF_._scoreBoard.prototype.parse_NBA = function()
{
	if (!this.xmlRequest) return;
	if (this.xmlRequest && !this.xmlRequest.responseText)
	// no data available
	{
		this.customText("Data Unavailable");
		return;
	}
	var theCurrentDate = new Date(new Date().valueOf() - 36000000 + (new Date().getTimezoneOffset() * 60000));
	this.theDateString = theCurrentDate.getFullYear() + WC_.twoDigNum(theCurrentDate.getMonth() + 1) + WC_.twoDigNum(theCurrentDate.getDate());
	if (this.scoreBoardLink && parseInt(this.scoreBoardLink) == parseInt(theCurrentDate))
		this.scoreBoardLink = null;
	this.isCurrentDay = !this.scoreBoardLink;
	if (!this.isCurrentDay)
		this.gameSortOrder = new Array();
	this.theDateString = (this.scoreBoardLink || this.theDateString) + "";
	if (SF_.prefs.currentLeague.match(/NBA/))
	{
		if (!this.gameDates.length)
			this._NBA_loadGameDates();
		// reload the game dates if we are past the last date in order to update with new games in the post season
		else if (this.gameDates[this.gameDates.length-1] < parseInt(this.theDateString))
			this._NBA_loadGameDates();
		var xmlResponse = this.xmlRequest.responseXML;
		if (!xmlResponse)
		// apparently nothing past <error>…</error> gets parsed - remove tag and try again
			xmlResponse = new DOMParser().parseFromString(this.xmlRequest.responseText.replace(/<error>.*<\/error>/g,""),"text/xml");
		if (!$x(xmlResponse,"message"))
		// XML data not yet/no longer available - get and parse HTML scoreboard
		{
			this.xmlRequest = new XMLHttpRequest();
			var _self = this;
			this.xmlRequest.onload = function() {_self.parse_NBA_HTML();}
			this.xmlRequest.open("GET","http://www." + (SF_.prefs.currentLeague == "WNBA" ? "w" : "") + "nba.com/gameline/" + (this.scoreBoardLink || this.theDateString) + "/");
			this.xmlRequest.setRequestHeader("Cache-Control", "no-cache");
			this.xmlRequest.setRequestHeader("Cookie", "");
			this.xmlRequest.send(null);
		}
		else
			this.parse_NBA_XML();
	}
	else
		this.parse_NCAAB();
}

SF_._scoreBoard.prototype.parse_NBA_XML = function()
{
	var xmlResponse = this.xmlRequest.responseXML;
	if (!xmlResponse)
		xmlResponse = new DOMParser().parseFromString(this.xmlRequest.responseText.replace(/<error>.*<\/error>/g,""),"text/xml");
	this.xmlRequest = null;
	// for dates without any games we get " <message id="-1" gdt="00000000" ></message>" - use the current date instead.
	this.theDateString = (parseInt($x(xmlResponse,"message","gdt"),10) || this.theDateString) + "";
	this.dates = [{games:[]}];
	if ($x(xmlResponse,"game"))
	{
		for (var iGame = 0, gameLen = $x(xmlResponse,"game").length; iGame < gameLen; iGame++)
		{
			var status = "";
			var homeScore = parseInt($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("scr").split("|")[$x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("scr").split("|").length-1] || 0, 10);
			var awayScore = parseInt($x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("scr").split("|")[$x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("scr").split("|").length-1] || 0, 10);
			var scoreDetails;
			var gameTime = $x(xmlResponse,"game","timet",iGame);
			switch($x(xmlResponse,"game","gstat",iGame))
			{
				case "1":
					status = "P";
					if ($x(xmlResponse,"game","gstattxt",iGame) == "TBA")
						scoreDetails = "TBA";
					else
					{
						gameTime = WC_.createDateFromTimeString($x(xmlResponse,"game","gstattxt",iGame).replace(/ET/,"E" + (this.isDST() ? "D" : "S") + "T")).getTime();
						scoreDetails = this.timeString(gameTime);
					}
					break;
				case "3":
					status = "F";
					scoreDetails = "Final" + (parseInt($x(xmlResponse,"game","prd",iGame), 10) < 5 ? "" : "/" + (parseInt($x(xmlResponse,"game","prd",iGame), 10) - 4) + "OT");
					break;
				default:
					status = "";
					scoreDetails = WC_.sanitizeString(($x(xmlResponse,"game","gstattxt",iGame).replace(/ Qtr/,"").replace(/([0-9]).*?OT/,"$1OT") + ($x(xmlResponse,"game","gstattxt",iGame).match(/(?:Halftime|Start of|End of) */) ? "" : ", " + $x(xmlResponse,"game","clk",iGame))).replace(/ +/g," "));
			}
			var gameDetails = null;
			if (status != "P")
			{
				var lineScore = {
					titleText: "",
					awayTeam: WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("tm").split("|")[1].replace(/ +/g," ").replace(/-/g,"&#8209;")),
					homeTeam: WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("tm").split("|")[1].replace(/ +/g," ").replace(/-/g,"&#8209;")),
					title: ["1","2","3","4","1OT","2OT","3OT","4OT"],
					awayScores: [],
					homeScores: [],
					possession: null
				}
				if (status == "")
				{
					lineScore.titleText = WC_.sanitizeString($x(xmlResponse,"game","gstattxt",iGame).replace(/ +/g," ") + ($x(xmlResponse,"game","clk",iGame) == " " ? "" : ", " + $x(xmlResponse,"game","clk",iGame)));
					if ($x(xmlResponse,"game","poss",iGame) == "a")
					{
						lineScore.awayTeam = "<span class='p'>" + lineScore.awayTeam + "</span>";
						lineScore.possession = "away";
					}
					else if ($x(xmlResponse,"game","poss",iGame) == "h")
					{
						lineScore.homeTeam = "<span class='p'>" + lineScore.homeTeam + "</span>";
						lineScore.possession = "home";
					}
				}
				else
				{
					lineScore.titleText = "Final" + (parseInt($x(xmlResponse,"game","prd",iGame), 10) < 5 ? "" : "/" + (parseInt($x(xmlResponse,"game","prd",iGame), 10) - 4) + "OT");
					if ($x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("rcd"))
						lineScore.awayTeam += " (" + WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("rcd").replace(/\//,"&#8209;")) + ")";
					if ($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("rcd"))
						lineScore.homeTeam += " (" + WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("rcd").replace(/\//,"&#8209;")) + ")";
				}
				lineScore.title.splice(Math.max(4,parseInt($x(xmlResponse,"game","prd",iGame),10)),8);
				for (var i = 0, len = Math.max(4,parseInt($x(xmlResponse,"game","prd",iGame),10)); i < len; i++)
				{
					lineScore.awayScores.push(i < parseInt($x(xmlResponse,"game","prd",iGame),10) ? WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("scr").split("|")[i]) : null);
					lineScore.homeScores.push(i < parseInt($x(xmlResponse,"game","prd",iGame),10) ? WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("scr").split("|")[i]) : null);
				}
				lineScore.awayScores.push(WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("scr").split("|")[$x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("scr").split("|").length-1]));
				lineScore.homeScores.push(WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("scr").split("|")[$x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("scr").split("|").length-1]));
				gameDetails = this.buildLineScoreTable(lineScore);
				gameDetails += "<div class='playInfo'>";
				if ($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("pld") && (homeScore + awayScore))
				{
					gameDetails += "<em>Point Leaders:</em><br />";
					if (awayScore)
					{
						for (var i = 0, len = $x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("pld").split("^").length; i < len; i++)
						{
							gameDetails += "<span" + (i ? " style='visibility:hidden;'>" : ">") + WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("tm").split("|")[3]) + ": </span>";
							var pointLeader = $x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("pld").split("^")[i];
							gameDetails += WC_.sanitizeString(pointLeader.split("|")[2] + " (" + pointLeader.split("|")[3]) + ")<br />";
						}
					}
					if (homeScore)
					{
						for (var i = 0, len = $x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("pld").split("^").length; i < len; i++)
						{
							gameDetails += "<span" + (i ? " style='visibility:hidden;'>" : ">") + WC_.sanitizeString($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("tm").split("|")[3]) + ": </span>";
							var pointLeader = $x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("pld").split("^")[i];
							gameDetails += WC_.sanitizeString(pointLeader.split("|")[2] + " (" + pointLeader.split("|")[3]) + ")<br />";
						}
					}
				}
				gameDetails += "</div>";
			}
			this.dates[0].games.push({
				gameID: $x(xmlResponse,"game","gcd",iGame),
				status: status,
				link: "http://www." + (SF_.prefs.currentLeague == "WNBA" ? "w" : "") + "nba.com/games/" + $x(xmlResponse,"game","gcd",iGame) + "/gameinfo.html",
				gameTime: gameTime,
				scoreDetails: scoreDetails,
				awayTeam: $x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("tm").split("|")[3],
				awayTeamDetails: $x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("tm").split("|")[1] +  ($x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("rcd") ? " (" + $x(xmlResponse,"game")[iGame].getElementsByTagName("vtm")[0].getAttribute("rcd").replace(/\//,"-") + ")" : ""),
				awayTeamClass: status == "" && $x(xmlResponse,"game","poss",iGame) == "a" ? "p" : "",
				awayScore: awayScore,
				homeTeam: $x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("tm").split("|")[3],
				homeTeamDetails: $x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("tm").split("|")[1] +  ($x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("rcd") ? " (" + $x(xmlResponse,"game")[iGame].getElementsByTagName("htm")[0].getAttribute("rcd").replace(/\//,"-") + ")" : ""),
				homeTeamClass: status == "" && $x(xmlResponse,"game","poss",iGame) == "h" ? "p" : "",
				homeScore: homeScore,
				gameDetails: gameDetails
			});
		}
	}
	this.draw();
}

SF_._scoreBoard.prototype.parse_NBA_HTML = function()
{
	var xmlResponse = this.xmlRequest.responseText;
	this.xmlRequest = null;
	xmlResponse = xmlResponse.replace(/[\n\r]/g,"");
	xmlResponse = xmlResponse.match(/<div class="nbaOuterBox.*?<div class="nbaBtm/g);
	if (!xmlResponse) xmlResponse = new Array();
	this.dates = [{games:[]}];
	for (var iGame in xmlResponse)
	{
		var theGame = xmlResponse[iGame];
		var gameID = ( theGame.match(/\/games\/(.*?)\/gameinfo/) ? theGame.replace(/.*\/games\/(.*?)\/gameinfo.*/,"$1") : iGame);
		var status = "";
		var gameTime = iGame;
		var scoreDetails = "";
		var awayTeamDetails = "";
		var homeTeamDetails = "";
		var awayTeam = awayTeamDetails;
		var homeTeam = homeTeamDetails;
		var gameDetails = null;
		var awayScore = 0;
		var homeScore = 0;
		if (theGame.match(/games\/[0-9]+\//))
		{
			awayTeam = theGame.replace(/.*?games\/[0-9]+\/(.{3}).*/,"$1");
			homeTeam = theGame.replace(/.*?games\/[0-9]+\/.{3}(.{3}).*/,"$1");
		}
		if (theGame.match(/nbaPreMnTmStdg/))
		{
			var teamStandings = theGame.match(/nbaPreMnTmStdg.*?<\/table>/)[0];
			awayTeamDetails = teamStandings.match(/<tr>.*?<\/tr>/g)[0].match(/<td.*?<\/td>/g);
			awayTeamDetails = SF_.teams[SF_.prefs.currentLeague][SF_.getTeamIndex("shortName",awayTeam)].fullName + " (" + (awayTeamDetails[0] + "-" + awayTeamDetails[1]).replace(/<.*?>/g,"") + ")";
			homeTeamDetails = teamStandings.match(/<tr>.*?<\/tr>/g)[1].match(/<td.*?<\/td>/g);
			homeTeamDetails = SF_.teams[SF_.prefs.currentLeague][SF_.getTeamIndex("shortName",homeTeam)].fullName + " (" + (homeTeamDetails[0] + "-" + homeTeamDetails[1]).replace(/<.*?>/g,"") + ")";
		}
		else
		{
			awayTeamDetails = SF_.getTeamIndex("shortName",awayTeam) >= 0 ? SF_.teams[SF_.prefs.currentLeague][SF_.getTeamIndex("shortName",awayTeam)].fullName : awayTeam;
			homeTeamDetails = SF_.getTeamIndex("shortName",homeTeam) >= 0 ? SF_.teams[SF_.prefs.currentLeague][SF_.getTeamIndex("shortName",homeTeam)].fullName : homeTeam;
		}
		if (theGame.match(/nbaPreMnPreview/))
		{
			status = "P";
			gameTime = WC_.createDateFromTimeString(theGame.replace(/.*?nbaPreMnStatus">(.*?)<div class="nbaPreMnTeamInfo.*/,"$1").replace(/.*?> */,"").replace(/<.*?>/g,"").replace(/ +/g," ").replace(/ET/i,"E" + (this.isDST() ? "D" : "S") + "T").replace(/([0-9])((?:a|p)m)/i,"$1 $2").toUpperCase()).getTime();
			scoreDetails = this.timeString(gameTime);
		}
		else if (theGame.match(/modLive/))
		{
			scoreDetails = theGame.replace(/.*?nbaLiveStatTxSm">(.*?)<.*/,"$1");	//"
		}
		else if (theGame.match(/gamestatustext Post/))
		{
			var thePeriod = theGame.match(/>[1-4]OT/) ? (parseInt(theGame.replace(/.*>([1-4])OT.*/,"$1"),10) + 4) : 4;
			status = "F";
			scoreDetails = "Final" + (thePeriod > 4 ? "/" + (thePeriod - 4) + "OT" : "");
			var lineScore = {
				titleText: scoreDetails,
				awayTeam: WC_.sanitizeString(awayTeamDetails),
				homeTeam: WC_.sanitizeString(homeTeamDetails),
				title: ["1","2","3","4","1OT","2OT","3OT","4OT"],
				awayScores: theGame.match(/<td[^>]*?vtm-scr.*?<\/td>/g).join("|").replace(/<.*?>/g,"").split("|"),
				homeScores: theGame.match(/<td[^>]*?htm-scr.*?<\/td>/g).join("|").replace(/<.*?>/g,"").split("|"),
				possession: null
			}
			lineScore.title.splice(thePeriod,8);
			lineScore.awayScores.splice(thePeriod,8 - thePeriod);
			lineScore.homeScores.splice(thePeriod,8 - thePeriod);
			gameDetails = this.buildLineScoreTable(lineScore);
			awayScore = parseInt(lineScore.awayScores[thePeriod],10);
			homeScore = parseInt(lineScore.homeScores[thePeriod],10);
		}
		this.dates[0].games.push({
			gameID: gameID,
			status: status,
			link: gameID != iGame ? "http://www." + (SF_.prefs.currentLeague == "WNBA" ? "w" : "") + "nba.com/games/" + gameID + "/gameinfo.html" : null,
			gameTime: gameTime,
			scoreDetails: scoreDetails,
			awayTeam: awayTeam,
			awayTeamDetails: awayTeamDetails,
			awayTeamClass: "",
			awayScore: awayScore,
			homeTeam: homeTeam,
			homeTeamDetails: homeTeamDetails,
			homeTeamClass: "",
			homeScore: homeScore,
			gameDetails: gameDetails
		});
	}
	this.draw();
}

SF_._scoreBoard.prototype.parse_NCAAB = function()
{
	var xmlResponse = this.xmlRequest.responseText;
	this.xmlRequest = null;
	xmlResponse = xmlResponse.replace(/[\n\r]/g,"");
	this.gameDates = xmlResponse.match(new RegExp("<a( +class=\"?opt(sel)?)?[ \"]+href[^>]*\/collegebasketball\/scoreboard\/" + this.scoreboardMainLink + "[^>]*>[^<]*[0-9]+<\/a>","g")) || [];
	this.gameDates = this.gameDates.join("|").replace(/<a.*?([0-9]+)["]*>[^>]*[0-9]+<\/a>/g,"$1").split("|"); //"
	this.gameDates.sort();
	if (xmlResponse.match(/<a class=optsel href.*?>/) && xmlResponse.match(/<a class=optsel href.*?>/g)[0].replace(/.*\/([0-9]+).*/,"$1") != this.theDateString)
		this.theDateString = xmlResponse.match(/<a class=optsel href.*?>/g)[0].replace(/.*\/([0-9]+).*/,"$1");
	else if (!xmlResponse.match(/<a class=optsel href.*?>/) && xmlResponse.match(/<a href=[^>]*gamecenter[^>]*NCAAB_[0-9]+/))
		this.theDateString = xmlResponse.match(/<a href=[^>]*gamecenter[^>]*NCAAB_[0-9]+/g)[0].replace(/.*_([0-9]+).*/,"$1");
	xmlResponse = xmlResponse.match(/<div[^>]+class=\"?scoreBox.*?<\/span>.*?links.*?<\/(div|table)><\/div>/g);	//" (code highlighting fix)
	if (!xmlResponse) xmlResponse = new Array();
	this.dates = [{games:[]}];
	for (var iGame in xmlResponse)
	{
		var theGame = xmlResponse[iGame];
		var gameID = (theGame.match(/gametracker/) ? theGame.replace(/.*?gametracker\/.*?\/([A-Z0-9_@]*).*/,"$1") : iGame);
		if (gameID == "")
			gameID = iGame;
		var gameCenterLink = null;
		if (gameID != iGame)
		{
			if (theGame.match(/gametracker\/live/))
				gameCenterLink = "http://www.cbssports.com/collegebasketball/" + theGame.replace(/.*?(gametracker\/live\/[A-Z0-9_@]*).*/,"$1");
			else
				gameCenterLink = "http://www.cbssports.com/collegebasketball/" + theGame.replace(/.*?(gametracker\/.*?\/[A-Z0-9_@]*).*/,"$1");
		}
		if (gameID == iGame && theGame.match(/gmtr_game/))
			gameID = theGame.replace(/.*?gmtr_game=([^ ]+).*/,"$1");
		var status = "";
		var scoreDetails = "";
		var awayTeam = "";
		var homeTeam = "";
		var gameDetails = null;
		var awayScore = 0;
		var homeScore = 0;
		if (gameID == iGame)
		{
			if (theGame.match(/<tr.*?<\/tr>/g)[1].match(/\/teams\/page/))
				awayTeam = theGame.match(/<tr.*?<\/tr>/g)[1].replace(/.*?\/teams\/page\/([A-Z]+).*/,"$1");
			else
				awayTeam = theGame.match(/<tr.*?<\/tr>/g)[1].replace(/.*?<b>(.*?)<\/b>.*/,"$1");
			if (theGame.match(/<tr.*?<\/tr>/g)[2].match(/\/teams\/page/))
				homeTeam = theGame.match(/<tr.*?<\/tr>/g)[2].replace(/.*?\/teams\/page\/([A-Z]+).*/,"$1");
			else
				homeTeam = theGame.match(/<tr.*?<\/tr>/g)[2].replace(/.*?<b>(.*?)<\/b>.*/,"$1");
		}
		else
		{
			awayTeam = gameID.replace(/.*_(.*?)@.*/,"$1");
			homeTeam = gameID.replace(/.*@([A-Z]*).*/,"$1");
		}
		var teamRank = "";
		if (theGame.match(new RegExp("\/teams\/page\/" + awayTeam + "(?:[^>]*>){4}[^>]*>#[0-9]+<.*?<\/tr>")))
			teamRank = WC_.sanitizeString(" (" + theGame.match(new RegExp("\/teams\/page\/" + awayTeam + ".*?<\/a>[^>]*>#[0-9]+<.*?<\/tr>"))[0].match(/>#[0-9]+/)[0].replace(/>/,"") + ")");
		awayTeamDetails = theGame.match(/<tr.*?<\/tr>/g)[1].replace(/.*?<b>(.*?)<\/b>.*/,"$1" + teamRank);
		teamRank = "";
		if (theGame.match(new RegExp("\/teams\/page\/" + homeTeam + "(?:[^>]*>){4}[^>]*>#[0-9]+<.*?<\/tr>")))
			teamRank = WC_.sanitizeString(" (" + theGame.match(new RegExp("\/teams\/page\/" + homeTeam + ".*?<\/a>[^>]*>#[0-9]+<.*?<\/tr>"))[0].match(/>#[0-9]+/)[0].replace(/>/,"") + ")");
		homeTeamDetails = theGame.match(/<tr.*?<\/tr>/g)[2].replace(/.*?<b>(.*?)<\/b>.*/,"$1" + teamRank);
		status = "";
		var gameTime = this.gameSortOrder[awayTeam + "@" + homeTeam] != null ? this.gameSortOrder[awayTeam + "@" + homeTeam] : iGame;
		if (!iGame && this.gameSortOrder[awayTeam + "@" + homeTeam] == null) this.gameSortOrder = [];
		var pointLeaders = "";
		if (theGame.match(/<b>Final<\/b>/))
		{
			status = "F";
			scoreDetails = "Final";
			if (theGame.match(/>[2-4]?OT/))
			{
				var otStrings = theGame.match(/>[2-4]?OT/g);
				scoreDetails += otStrings[otStrings.length-1].replace(/>/,"/");
			}
			if (theGame.match(/<span[^>]+plays.*?>.*?<\/span>/) && theGame.replace(/.*?<span[^>]+plays.*?> *(.*?) *<\/span>.*/,"$1") != "")
			{
				pointLeaders = "<div class='playInfo'><em>Point Leaders:</em><br />";
				if (theGame.match(/<span[^>]+plays.*?>.*?<\/span>/)[0].match(/.*?<\/b><br>.*?- +(.*?) \((.*?)\).*/))
					pointLeaders += WC_.sanitizeString(theGame.match(/<span[^>]+plays.*?>.*?<\/span>/)[0].replace(/.*?<\/b><br>.*?- +(.*?) \((.*?)\).*/,awayTeam + ": $1 ($2)").replace(/(?:&nbsp;| +)/g," ").replace(/-/g,"&#8209;")) + "<br />";
				if (theGame.match(/<span[^>]+plays.*?>.*?<\/span>/)[0].match(/.*?<\/b><br>.*?<br>.*?- +(.*?) \((.*?)\).*/))
					pointLeaders += WC_.sanitizeString(theGame.match(/<span[^>]+plays.*?>.*?<\/span>/)[0].replace(/.*?<\/b><br>.*?<br>.*?- +(.*?) \((.*?)\).*/,homeTeam + ": $1 ($2)").replace(/(?:&nbsp;| +)/g," ").replace(/-/g,"&#8209;"));
			}
		}
		else if (theGame.match(/document\.write\(formatTime/))
		{
			status = "P";
			gameTime = 1000 * parseInt(theGame.replace(/.*formatTime.*?,\s*([0-9]*).*/,"$1"),10);
			scoreDetails = this.timeString(gameTime);
		}
		else if (theGame.match(/<b>TBA<\/b>/))
		{
			status = "P";
			scoreDetails = "TBA";
		}
		else
		{
			if (theGame.match(/.*?<b>([0-9:\.]+) left in ([^<]+).*/))
				scoreDetails = WC_.sanitizeString(theGame.replace(/.*?<b>([0-9:\.]+) left in ([^<]+).*/,"$2, $1"));
			else
				scoreDetails = WC_.sanitizeString(theGame.replace(/.*?<b>(.*?)<\/b>.*/,"$1"));
			if (theGame.match(/<span[^>]+plays.*?>.*?<\/span>/))
			{
				pointLeaders = "<div class='playInfo'><em>Point Leaders:</em><br />";
				if (theGame.match(/<span[^>]+plays.*?>.*?<\/span>/)[0].match(/.*?:<\/td><td>(.*?), ([0-9]+).*/))
					pointLeaders += WC_.sanitizeString(theGame.match(/<span[^>]+plays.*?>.*?<\/span>/)[0].replace(/.*?:<\/td><td>(.*?), ([0-9]+).*/,awayTeam + ": $1 ($2)").replace(/(?:&nbsp;| +)/g," ").replace(/-/g,"&#8209;")) + "<br />";
				if (theGame.match(/<span[^>]+plays.*?>.*?<\/span>/)[0].match(/.*?:<\/td>.*?:<\/td><td>(.*?), ([0-9]+).*/))
					pointLeaders += WC_.sanitizeString(theGame.match(/<span[^>]+plays.*?>.*?<\/span>/)[0].replace(/.*?:<\/td>.*?:<\/td><td>(.*?), ([0-9]+).*/,homeTeam + ": $1 ($2)").replace(/(?:&nbsp;| +)/g," ").replace(/-/g,"&#8209;"));
			}
		}
		if (this.isCurrentDay)
			this.gameSortOrder[awayTeam + "@" + homeTeam] = gameTime;
		if (status != "P")
		{
			var thePeriod = theGame.match(/>OT/) ? 3 : 2;
			if (theGame.match(/>[2-4]OT/))
			{
				var otStrings = theGame.match(/>[2-4]OT/g);
				thePeriod += parseInt(otStrings[otStrings.length-1].replace(/>/,"").replace(/OT/,"")) - 1;
			}
			var lineScore = {
				titleText: scoreDetails,
				awayTeam: WC_.sanitizeString(awayTeamDetails),
				homeTeam: WC_.sanitizeString(homeTeamDetails),
				title: ["1","2","OT","2OT","3OT","4OT"],
				awayScores: theGame.match(/<tr.*?<\/tr>/g)[1].match(/<td[^>]*align=\"?center.*?<\/td>/g).join("|").replace(/<.*?>/g,"").replace(/&nbsp;/g,"").split("|"),	//"
				homeScores: theGame.match(/<tr.*?<\/tr>/g)[2].match(/<td[^>]*align=\"?center.*?<\/td>/g).join("|").replace(/<.*?>/g,"").replace(/&nbsp;/g,"").split("|"),	//"
				possession: null
			}
			lineScore.title.splice(thePeriod,4);
			gameDetails = this.buildLineScoreTable(lineScore) + pointLeaders + "</div>";
			awayScore = parseInt(lineScore.awayScores[thePeriod],10);
			homeScore = parseInt(lineScore.homeScores[thePeriod],10);
		}
		this.dates[0].games.push({
			gameID: gameID,
			status: status,
			link: gameCenterLink,
			gameTime: gameTime,
			scoreDetails: scoreDetails,
			awayTeam: awayTeam,
			awayTeamDetails: awayTeamDetails,
			awayTeamClass: "",
			awayScore: awayScore,
			homeTeam: homeTeam,
			homeTeamDetails: homeTeamDetails,
			homeTeamClass: "",
			homeScore: homeScore,
			gameDetails: gameDetails
		});
	}
	this.draw();
}

SF_._scoreBoard.prototype.parse_NFL = function()
{
	if (!this.xmlRequest) return;
	if (this.xmlRequest && !this.xmlRequest.responseText)
	// no data available
	{
		this.customText("Data Unavailable");
		return;
	}
	var xmlResponse = this.xmlRequest.responseText;
	this.xmlRequest = null;
	xmlResponse = xmlResponse.replace(/[\n\r]/g,"");
	// let's cut down the length of our result since non-greedy matching seems to have a maximum length of the non-greedy match
	xmlResponse = xmlResponse.replace(/<table[^>]*>/g,"<table>").replace(/(?:v?align|height|border|width|cellspacing|cellpadding)=[^ >]*?(left)?>/g,"$1>").replace(/<a href=\/login.*?<\/a>/g,"").replace(/javascript:openPopup\([^)]*\)/g,"").replace(/<b>&#183;<\/b>/g,"");
	var theWeek = WC_.sanitizeString(xmlResponse.match(/class="?optsel.*?week[0-9]+/) ? xmlResponse.match(/class="?optsel.*?week[0-9]+/)[0].replace(/.*?scoreboard\/(?:1A\/)?([0-9]{4})?.*?(preseason)?\/week([0-9]*)/,"$2 $3 $1") : "");
	this.byeWeekTeams = xmlResponse.match(/<div[^>]* class="opendate[^>]*>.*?<\/div>/);	//"
	if (this.byeWeekTeams)
		this.byeWeekTeams = WC_.sanitizeString(this.byeWeekTeams[0].replace(/<.*?>/g,"").replace(/.*?:/,""));
	this.isCurrentDay = !this.scoreBoardLink;
	if (!this.isCurrentDay)
		this.gameSortOrder = new Array();
	this.updateTitleMenu(theWeek.split(" "));
	this.dates = new Array();
	var theDates = xmlResponse.match(/(<(div|td) class="date"|"scoresDate")>.*?(<\/(div|table)><br>|<div class="clearBoth"><\/div>(<div (class|id="?sound)|\s*<(\/div><!--|script|\/td)))/gm) || []; //"
	for (var iDate in theDates)
	{
		var theDate = theDates[iDate];
		this.dates.push({date:WC_.sanitizeString(theDate.replace(/<.*? [^>]*>([^<]*).*/,"$1").replace(/(?:.*>)(.*)/,"$1")), games:[]});
		var dateIndex = new Date(this.dates[iDate].date).getTime();
		this.gameSortOrder[dateIndex] = this.gameSortOrder[dateIndex] || [];
		var theGames = theDate.match(/<div id="scores-.*?<(td|span) id="(expand)?links.*?<\/table>/g);
		for (var iGame in theGames)
		{
			var theGame = theGames[iGame];
			var keepGame = SF_.prefs.favoriteLeague < 2;
			if (!keepGame)
			{
				if (SF_.prefs.favoriteLeague == 2)
					keepGame = !(!theGame.match(/rank.>#[0-9]+</));
				else
				{
					var theTeams = theGame.match(/\/teams\/.*?\/[^\"]*">/g) || theGame.match(/\/teams\/roster\/[^>]*>/g);
					if (theTeams)
					{
						var teamsStart = SF_.leagues[SF_.prefs.currentSport][SF_.prefs.favoriteLeague].startIndex;
						var teamsEnd = SF_.leagues[SF_.prefs.currentSport][SF_.prefs.favoriteLeague].endIndex;
						var teamIndex = SF_.getTeamIndex("shortName",theTeams[0].replace(/[^>]*\/([A-Z]{2,7})[\/\"].*/,"$1")); //"
						keepGame = (teamIndex >= teamsStart && teamIndex <= teamsEnd);
						if (!keepGame && theTeams.length > 1)
						{
							teamIndex = SF_.getTeamIndex("shortName",theTeams[1].replace(/[^>]*\/([A-Z]{2,7})[\/\"].*/,"$1")); //"
							keepGame = (teamIndex >= teamsStart && teamIndex <= teamsEnd);						
						}
					}
				}
			}
			if (keepGame)
			{
				var gameID = iDate + "_" + iGame;
				if (theGame.match(/game(?:center|tracker)\/live/))
					gameID = theGame.replace(/.*?\/game(?:center|tracker)\/live\/([^>]*).*/,"$1");
				var status = "";
				var scoreDetails = "";
				var gameDetails = null;
				var awayScore = 0;
				var homeScore = 0;
				var possession = -1;
				var inRedZone = false;
				var location = "";
				theGame = theGame.replace(/<a [^>]*>(?:Recap|GameCenter|Glog \(Live Commentary\))<\/a>/g,"");
				if (theGame.match(/Ball on:/))
					location = WC_.sanitizeString(theGame.replace(/.*?Ball on:.*?>(.*?[0-9]+).*/,"$1"));
				else if (theGame.match(/ball on/))
					location = WC_.sanitizeString(theGame.replace(/.*?ball on *(.*?[0-9]+).*/,"$1"));
				if (location.match(/Last Play:/) && theGame.match(/To Go: *<\/b>Goal/))
					location = "";
				var awayTeam = theGame.match(/class="name" >(<img[^<]*>)?(<[^<]*?\/teams\/page\/.*?[^\"]*">)?(<b>)?[^<]+<\/(a|b)>.*?<\/td>/g)[0];
				if (awayTeam.match(/<\/tr>/))
					awayTeam = theGame.match(/left>(<img[^<]*>)?(<[^<]*?\/teams\/.*?\/[^\"]*">)?(<b>)?[^<]+<\/(a|b)>.*?<\/tr>/g)[0];
				awayTeam = awayTeam.replace(/class="name" >/,"").replace(/<img[^<]*\/[A-Z]{2,}\.gif>/,"").replace(/<img[^<]*\/images\/icon.*?>/g,"").replace(/<img[^<]*\/logos\/.*?>/g,"").replace(/<[^>]*scorerow.*/,"");
				var awayTeamDetails;
				if (SF_.prefs.currentLeague != "NFL" || awayTeam.match(/[AN]FC/))
					awayTeamDetails = awayTeam.replace(/.*b>(.*?)<\/b>.*/,"$1");
				else
					awayTeamDetails = awayTeam.replace(/.*>(.*?)<\/a>.*/,"$1");
				if (awayTeam.match(/rank.>#[0-9]+</))
					awayTeamDetails += awayTeam.replace(/.*?rank.>(#[0-9]+)<.*/," ($1)");
				if (awayTeam.match(/[\(>][0-9]+-[-0-9]+[<\)]/))
					awayTeamDetails += awayTeam.replace(/.*?[\(>]([0-9]+-[-0-9]+)[<\)].*/," ($1)");
				if (awayTeam.match(/<img/))
					possession = 0;
				if (awayTeam.match(/teams\/page\//))
					awayTeam = awayTeam.replace(/[^>]*\/([A-Z]{2,8})[\/\"].*/,"$1"); //"
				else if (awayTeam.match(/b>.*?<\/b/))
					awayTeam = awayTeam.replace(/.*b>(.*?)<\/b>.*/,"$1")
				else
				{
					if (SF_.prefs.currentLeague != "NFL" && theGame.match(/\/teams\/roster\/[^>]*>/) && theGame.match(/\/teams\/roster\/[^>]*>/g).length == 2)
						awayTeam = theGame.match(/\/teams\/roster\/[^>]*>/g)[0].replace(/[^>]*\/([A-Z]{2,7})[\/\"].*/,"$1"); //"
					else
						awayTeam = awayTeam.replace(/<[^>]*>/g,"").replace(/\([0-9]+-[0-9]+\)/,"").replace(/&nbsp;.*/g,"");
				}
				var homeTeam = theGame.match(/class="name" >(<img[^<]*>)?(<[^<]*?\/teams\/page\/.*?[^\"]*">)?(<b>)?[^<]+<\/(a|b)>.*?<\/td>/g)[1];
				if (!homeTeam || homeTeam.match(/<\/tr>/))
					homeTeam = theGame.match(/left>(<img[^<]*>)?(<[^<]*?\/teams\/.*?\/[^\"]*">)?(<b>)?[^<]+<\/(a|b)>.*?<\/tr>/g)[1];
				homeTeam = homeTeam.replace(/class="name" >/,"").replace(/<img[^<]*\/[A-Z]{2,}\.gif>/,"").replace(/<img[^<]*\/images\/icon.*?>/g,"").replace(/<img[^<]*\/logos\/.*?>/g,"").replace(/<[^>]*scorerow.*/,"");
				var homeTeamDetails;
				if (SF_.prefs.currentLeague != "NFL" || homeTeam.match(/[AN]FC/))
					homeTeamDetails = homeTeam.replace(/.*b>(.*?)<\/b>.*/,"$1");
				else
					homeTeamDetails = homeTeam.replace(/.*>(.*?)<\/a>.*/,"$1");
				if (homeTeam.match(/rank.>#[0-9]+</))
					homeTeamDetails += homeTeam.replace(/.*?rank.>(#[0-9]+)<.*/," ($1)");
				if (homeTeam.match(/[\(>][0-9]+-[-0-9]+[<\)]/))
					homeTeamDetails += homeTeam.replace(/.*?[\(>]([0-9]+-[-0-9]+)[<\)].*/," ($1)");
				if (homeTeam.match(/<img/))
					possession = 1;
				if (homeTeam.match(/teams\/page\//))
					homeTeam = homeTeam.replace(/[^>]*\/([A-Z]{2,8})[\/\"].*/,"$1"); //"
				else if (homeTeam.match(/b>.*?<\/b/))
					homeTeam = homeTeam.replace(/.*b>(.*?)<\/b>.*/,"$1")
				else
				{
					if (SF_.prefs.currentLeague != "NFL" && theGame.match(/\/teams\/roster\/[^>]*>/))
						homeTeam = theGame.match(/\/teams\/roster\/[^>]*>/g)[theGame.match(/\/teams\/roster\/[^>]*>/g).length-1].replace(/[^>]*\/([A-Z]{2,7})[\/\"].*/,"$1"); //"
					else
						homeTeam = homeTeam.replace(/<[^>]*>/g,"").replace(/\([0-9]+-[0-9]+\)/,"").replace(/&nbsp;.*/g,"");
				}
				var awayTeamClass = "";
				var homeTeamClass = "";
				var inRedZone = false;
				switch (possession)
				{
					case 0:
						if (location.split(" ").length > 1 && location.split(" ")[0] == homeTeam && parseInt(location.split(" ")[1],10) <= 20)
						{
							awayTeamClass = "p redZone";
							inRedZone = true;
						}
						else
							awayTeamClass = "p";
						break;
					case 1:
						if (location.split(" ").length > 1 && location.split(" ")[0] == awayTeam && parseInt(location.split(" ")[1],10) <= 20)
						{
							homeTeamClass = "p redZone";
							inRedZone = true;
						}
						else
							homeTeamClass = "p";
						break;
				}
				var gameTime = this.gameSortOrder[dateIndex][awayTeam + "@" + homeTeam] != null ? this.gameSortOrder[dateIndex][awayTeam + "@" + homeTeam] : iGame;
				if (!iGame && this.gameSortOrder[dateIndex][awayTeam + "@" + homeTeam] == null)
					this.gameSortOrder[dateIndex] = [];
				if (theGame.match(/>Final[ OT]*<\//))
				{
					status = "F";
					awayScore = parseInt(theGame.match(/finalscore.*?>(<b>)?.*?<\//g)[0].replace(/.*>(.*?)<\//,"$1"),10);
					homeScore = parseInt(theGame.match(/finalscore.*?>(<b>)?.*?<\//g)[1].replace(/.*>(.*?)<\//,"$1"),10);
					scoreDetails = "Final" + (theGame.match(/>OT/) ? "/OT" : "");
				}
				else if (theGame.match(/data-gmt/))
				{
					status = "P";
					gameTime = 1000 * parseInt(theGame.replace(/.*data-gmt=['\"]([0-9]*).*/,"$1"),10); //'
					scoreDetails = this.timeString(gameTime);
				}
				else if (theGame.match(/<b>TBA<\/b>/))
				{
					status = "P";
					scoreDetails = "<em>TBA</em>";
				}
				else if (theGame.match(/<b>Postponed<\/b>/))
				{
					status = "P";
					scoreDetails = "<em>Postponed</em>";
				}
				else
				{
					awayScore = parseInt(theGame.match(/([0-9]+<\/b>|finalscore"?>[0-9]+)<\/td><\/tr>/g)[0].replace(/.*?([0-9]+).*/,"$1"),10);	//"
					homeScore = parseInt(theGame.match(/([0-9]+<\/b>|finalscore"?>[0-9]+)<\/td><\/tr>/g)[1].replace(/.*?([0-9]+).*/,"$1"),10);	//"
					scoreDetails = theGame.match(/<span id="?board.*?<td.*?<\/td>/) ? theGame.match(/<span id="?board.*?<td.*?<\/td>/)[0].replace(/<.*?>/g,"") : "";
					if (!scoreDetails.match(/(QTR|Halftime)/) && theGame.match(/bg1.*?>.*?<\/td>/))
						scoreDetails = theGame.match(/bg1.*?>.*?<\/td>/)[0].replace(/bg1.*?>/,"").replace(/<.*?>/g,"");
					scoreDetails = WC_.sanitizeString(scoreDetails.replace(/<.*?>/g,"").replace(/ *QTR/,"").replace(/ +/g," ").replace(/.*(Halftime).*/,"$1").replace(/^\s*/, "").replace(/\s*$/, ""));
				}
				if (this.isCurrentDay)
					this.gameSortOrder[dateIndex][awayTeam + "@" + homeTeam] = gameTime;
				if (status != "P")
				{
					var theQuarter = theGame.match(/>OT/) ? 5 : 4;
					var awayScores = WC_.sanitizeString(theGame.replace(/<img[^<]*\/[A-Z]{2,}\.gif>/,"").replace(/<\/?a.*?>/g,"").replace(/<td\s+class=timeouts>.*?<\/td>/g,"").replace(/<td\s+class=name.*?>/g,"").replace(/(<[^ >]+).*?>/g,"$1>").match(/<tr.*?<\/tr>/g)[1].replace(/.*?<\/b>/,"").match(/<td.*?<\/td>/g).join("|").replace(/<.*?>/g,"").replace(/&nbsp;/g,"")).split("|");
					if (SF_.prefs.currentLeague == "NFL")
						awayScores.splice(0,1);
					while (awayScores.length <= theQuarter)
						awayScores.splice(awayScores.length - 1, 0, "");
					var homeScores = WC_.sanitizeString(theGame.replace(/<img[^<]*\/[A-Z]{2,}\.gif>/,"").replace(/<\/?a.*?>/g,"").replace(/<td\s+class=timeouts>.*?<\/td>/g,"").replace(/<td\s+class=name.*?>/g,"").replace(/(<[^ >]+).*?>/g,"$1>").match(/<tr.*?<\/tr>/g)[2].replace(/.*?<\/b>/,"").match(/<td.*?<\/td>/g).join("|").replace(/<.*?>/g,"").replace(/&nbsp;/g,"")).split("|");
					if (SF_.prefs.currentLeague == "NFL")
						homeScores.splice(0,1);
					while (homeScores.length <= theQuarter)
						homeScores.splice(homeScores.length - 1, 0, "");
					var lineScore = {
						titleText: scoreDetails,
						awayTeam: WC_.sanitizeString(awayTeamDetails),
						homeTeam: WC_.sanitizeString(homeTeamDetails),
						title: ["1","2","3","4","OT"],
						awayScores: awayScores,
						homeScores: homeScores,
						possession: possession < 0 ? null : possession == 0 ? "away" : "home"
					}
					lineScore.title.splice(theQuarter,5);
					gameDetails = this.buildLineScoreTable(lineScore) + "<div class='playInfo'>";
					var inGameInfo = theGame.match(/<(div|span) id="plays.*?>.*?<\/div>/) ? theGame.replace(/.*?<(?:div|span) id="plays.*?>(.*?)<\/div>.*/,"$1").replace(/<\/?a.*?>/g,"") : "";
					if (inGameInfo.match(/^ *$/) && scoreDetails.match(/Halftime/) && theGame.match(/<div[^>]+class="sbGameLeaders".*?>.*?<\/div>/))
						inGameInfo = theGame.match(/<div[^>]+class="sbGameLeaders".*?>.*?<\/div>/)[0];
					if (inGameInfo.match(/(?:Game|Halftime) Leaders/))
					{
						inGameInfo = inGameInfo.replace(/<\/?a.*?>/g,"").replace(/(<[^ >]+).*?>/g,"$1>");
						inGameInfo = inGameInfo.replace(/(.*?)<\/tr>.*?<\/td><td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*/,"$1• $2:– $4 $5, $7 $8, $10 $11, • $3:– $4 $6, $7 $9, $10 $12");
					}
					var moreDetails = null;
					if (inGameInfo.match(/<span class="?playreview"?>.*?<\/span>/))
					{
						moreDetails = WC_.sanitizeString(inGameInfo.replace(/.*?<span class="?playreview"?>(.*?)<\/span>.*/,"$1").replace(/<.*?>/g,""));
						inGameInfo = inGameInfo.replace(/<span class="?playreview"?>.*?<\/span>/,"").replace(/\*\*\* *play under review *\*\*\*/,"").replace(/\*{3}/g,"");
					}	
					if (inGameInfo.match(/<div><b>ALERT:.*?<\/div>/))
					{
						moreDetails = WC_.sanitizeString(inGameInfo.replace(/.*?<div><b>(ALERT:.*?)<\/div>.*/,"$1").replace(/<.*?>/g,""));
						inGameInfo = inGameInfo.replace(/<div><b>ALERT:.*?<\/div>/,"");
					}
					if (moreDetails)
						gameDetails += "<div class='alertRow'>" + moreDetails + "</div>";
					if (inGameInfo.match(/.*?([1-4])(?:st|nd|rd|th).*?and.*?([0-9]+|Goal).*?ball on (.*?[0-9]+).*?<br>.*/))
					{
						moreDetails = inGameInfo.replace(/.*?([1-4])(?:st|nd|rd|th).*?and.*?([0-9]+|Goal).*?ball on (.*?[0-9]+).*?<br>(.*)/,"$1|$2|$3|$4").split("|");
						inGameInfo = moreDetails[3];
					}
					else if (inGameInfo.match(/.*?Down:.*?([1-4]).*?To Go:.*?([0-9]+|Goal).*?Ball on:.*?>(.*?[0-9]+).*/))
					{
						moreDetails = inGameInfo.replace(/.*?Down:.*?([1-4]).*?To Go:.*?([0-9]+|Goal).*?Ball on:.*?>(.*?[0-9]+)(.*)/,"$1|$2|$3|$4").split("|");
						inGameInfo = (location == "" ? moreDetails[2] : "") + moreDetails[3];
					}
					else
						moreDetails = null;
					if (moreDetails)
						gameDetails += "<div class='dateRow'>" + moreDetails[0] + "-" + moreDetails[1] + (location == "" ? "" : " @ " + (inRedZone ? "<span class='redZone'>" : "") + WC_.sanitizeString(moreDetails[2]) + (inRedZone ? "</span>" : "")) + "</div>";
					inGameInfo = WC_.sanitizeString(inGameInfo.replace(/<.*?>/g,""));
					inGameInfo = inGameInfo.replace(/(SAFETY|TOUCHDOWN|(?:extra point|[0-9]+ yard field goal) is GOOD|made (?:the extra point|a field goal of [0-9]+ yards))/gi,"<span class='w'>$1</span>").replace(/(TWO-POINT CONVERSION ATTEMPT)(.*?)(ATTEMPT SUCCEEDS)/i,"<span class='w'>$1</span>$2<span class='w'>$3</span>");
					inGameInfo = inGameInfo.replace(/((?:Game|Halftime) Leaders)/,"<em>$1</em><br />").replace(/(\s[A-Z]\.) /g,"$1 ").replace(/[ ]*\(/g," (").replace(/-/g,"&#8209;").replace(/\),/g,")<br />").replace(/\)([A-Z]{2,3}[:  ])/g,")<br />$1").replace(/([0-9]) yard/g,"$1 yard").replace(/:–/g,":<br />").replace(/GameTracker/g,"");
					gameDetails += inGameInfo + "</div>";
				}
				this.dates[iDate].games.push({
					gameID: gameID,
					status: status,
					link: gameID.match(/@/) ? ("http://www.sportsline.com/" + (SF_.prefs.currentLeague == "NFL" ? "nfl" : "collegefootball") + "/gamecenter/live/" + gameID) : null,
					gameTime: gameTime,
					scoreDetails: scoreDetails,
					awayTeam: awayTeam,
					awayTeamDetails: awayTeamDetails,
					awayTeamClass: awayTeamClass,
					awayScore: parseInt(awayScore || 0, 10),
					homeTeam: homeTeam,
					homeTeamDetails: homeTeamDetails,
					homeTeamClass: homeTeamClass,
					homeScore: parseInt(homeScore || 0, 10),
					gameDetails: gameDetails
				});
			}
		}
	}
	this.draw();
}

SF_._scoreBoard.prototype.updateTitleMenu_NFL = function(theWeek)
{
	if (!theWeek) return;
	if (this.isCurrentDay)
	{
		var theYear = parseInt(theWeek[2], 10) || "";
		// create week selection popup menu
		var weekPopupContent = "<div id='weekLabel'></div><select id='weekSel' onmouseup='SF_.theScoreBoard.scoreBoardLink=this.value;SF_.theScoreBoard.load();'>";
		if (SF_.prefs.currentLeague == "NFL")
		{
			// no preseason for college football
			weekPopupContent += "<optgroup label='Preseason'><option value='" + theYear + "/preseason/week0'>Hall of Fame Weekend</option>";
			for (var iWeekNum = 1; iWeekNum <= 4; iWeekNum++)
				weekPopupContent += "<option value='" + theYear + "/preseason/week" + iWeekNum + "'>Preseason Week " + iWeekNum + "</option>";
			weekPopupContent += "</optgroup><optgroup label='Regular Season'>";
		}
		// take into account that the college football season is shorter
		for (var iWeekNum = 1; iWeekNum <= (SF_.prefs.currentLeague == "NFL" ? 17 : 16); iWeekNum++)
			weekPopupContent += "<option value='" + (SF_.prefs.currentLeague == "NFL" ? "" : "1A" + "/") + theYear + "/week" + iWeekNum + "'>" + (SF_.prefs.currentLeague != "NFL" && iWeekNum == 16 ? "Bowls": "Week " + iWeekNum) + "</option>";
		if (SF_.prefs.currentLeague == "NFL")
			weekPopupContent += "</optgroup><optgroup label='Postseason'>"
				+ "<option value='" + theYear + "/week18'>Wild Card</option>"
				+ "<option value='" + theYear + "/week19'>Divisional Playoffs</option>"
				+ "<option value='" + theYear + "/week20'>Conference Championship</option>"
				+ "<option value='" + theYear + "/week21'>Pro Bowl</option>"
				+ "<option value='" + theYear + "/week22'>Super Bowl</option></optgroup>";
		weekPopupContent += "</select>";
		$("titleMenu").innerHTML = weekPopupContent;
	}
	var currentWeek = (theWeek[0] == "" ? parseInt(theWeek[1], 10) + (SF_.prefs.currentLeague == "NFL" ? 4 : -1) : parseInt(theWeek[1], 10));
	// fix for NFL postseason
	if (currentWeek == null || theWeek.length < 2)
		currentWeek = parseInt(this.scoreBoardLink.replace(/.*week(.*)/,"$1"),10) + 4;
	currentWeek = Math.min(currentWeek,$("weekSel").length);
	$("weekSel").selectedIndex = currentWeek;
	// make sure to re-enable auto-refresh for current week's scoreboard
	if (this.isCurrentDay)
		$("weekSel")[currentWeek].value = "";
	$s("weekLabel").marginLeft = "";
	$("weekLabel").innerText = $("weekSel").options[currentWeek].innerHTML;
	$s("weekSel").width = $("weekLabel").offsetWidth + "px";
	$s("weekSel").marginLeft = $s("weekLabel").marginLeft = (-$("weekLabel").offsetWidth/2) + "px";
	if (this.isCurrentDay)
		$("weekSel").options[currentWeek].innerHTML += " (current)";
}

SF_._scoreBoard.prototype.parse_MLB = function()
{
	if (!this.xmlRequest) return;
	this.theDateString = (this.scoreBoardLink || this._MLB_getDateString()).replace(/[^0-9]/g,"");
	this.dates = [{games:[]}];
	this.isCurrentDay = !this.scoreBoardLink || this.scoreBoardLink == (this._MLB_getDateString() + "/miniscoreboard.xml");
	if (this.isCurrentDay)
	{
		this.dayOffset = 0;
		this.scoreBoardLink = null;
	}
	else
		this.dayOffset = (new Date(parseInt(this.scoreBoardLink.split("_")[1],10),parseInt(this.scoreBoardLink.split("_")[2],10)-1,parseInt(this.scoreBoardLink.split("_")[3],10)).getTime() - new Date(parseInt(this._MLB_getDateString().split("_")[1],10),parseInt(this._MLB_getDateString().split("_")[2],10)-1,parseInt(this._MLB_getDateString().split("_")[3],10)).getTime())/86400000;
	this.gameDates = [this._MLB_getDateString(this.dayOffset-1),this._MLB_getDateString(this.dayOffset+1)];
	if (this.xmlRequest.status == "404")
	{
		this.xmlRequest = null;
		this.draw();
		return;
	}
	if (this.xmlRequest && !this.xmlRequest.responseText)
	{
		this.xmlRequest = null;
		this.customText("Data Unavailable");
		return;
	}
	var xmlResponse = this.xmlRequest ? this.xmlRequest.responseXML : null;
	if (!xmlResponse || !$x(xmlResponse,"games"))
	// no games on for the current date - create new date header so we can keep paging nevertheless
	{
		this.xmlRequest = null;
		this.draw();
		return;
	}
	// try to fix invalid XML (use of "&" instead of "&amp;" in query strings)
	// we see this for e.g., http://gdx.mlb.com/components/game/mlb/year_2007/month_05/day_02/miniscoreboard.xml
	if (!$x(xmlResponse,"game"))
		xmlResponse = new DOMParser().parseFromString(this.xmlRequest.responseText.replace(/&([^;]*?=)/g,"&amp;$1"),"text/xml");
	this.xmlRequest = null;
	if (!$x(xmlResponse,"game"))
	// no games on for the current date - create new date header so we can keep paging nevertheless
	{
		this.draw();
		return;
	}
	for (var iGame = 0, gameLen = $x(xmlResponse,"game").length; iGame < gameLen; iGame++)
	{
		// only show games for the leagues we display (as well as inter-league for NL and AL)
		// - e.g., don't show exhibition games
		if ($x(xmlResponse,"game","league",iGame).match(SF_.leagues["Baseball"][SF_.prefs.favoriteLeague].scoreBoardFilter))
		{
			var gameID = $x(xmlResponse,"game","gameday_link",iGame);
			var link = $x(xmlResponse,"game","gameday_link",iGame);
			if (link.match(/javascript/))
				link = link.replace(/.*lurl[ :']+(.*?)['}].*/,"$1");
			switch (SF_.prefs.currentLeague)
			{
				case "MLB":
					if ($x(xmlResponse,"game","wrapup_link",iGame))
						link = "http://mlb.mlb.com/mlb/gameday/index.jsp?gid=" + link + "&mode=wrap";
					else
						link = "http://mlb.mlb.com/news/boxscore.jsp?gid=" + link;
					break;
				default:
					link = "http://web.minorleaguebaseball.com/milb/stats/stats.jsp?t=g_box&gid=" + link;
					break;
			}
			var gameTime = WC_.createDateFromTimeString(($x(xmlResponse,"game","time",iGame) + " " + ($x(xmlResponse,"game","ampm",iGame) || "") + " E" + (this.isDST() ? "D" : "S") + "T")).getTime() || iGame;
			if ((gameTime == iGame) && iGame && this.dates[0].games[iGame - 1])
				// make sure we sort "Game 2" after the first game on the scoreboard
				gameTime = this.dates[0].games[iGame - 1].gameTime + 1;
			var status;
			var scoreDetails = "";
			var gameDetails = null;
			switch ($x(xmlResponse,"game","status",iGame))
			{
				// see <http://mlb.mlb.com/flash/scoreboard/y2007/sb_rules.xml> for list of game status codes
				case "Final":
				case "Game Over":
				case "Completed Early":
				case "Forfeit":
					scoreDetails = this._MLB_buildScoreDetails("F",$x(xmlResponse,"game","inning",iGame));
					status = "F";
					break;
				case "In Progress":
					if ($x(xmlResponse,"game","inning",iGame))
						scoreDetails = this._MLB_buildScoreDetails("I", $x(xmlResponse,"game","inning",iGame), $x(xmlResponse,"game","top_inning",iGame) == "Y", $x(xmlResponse,"game","outs",iGame), $x(xmlResponse,"game","runner_on_1b",iGame), $x(xmlResponse,"game","runner_on_2b",iGame), $x(xmlResponse,"game","runner_on_3b",iGame));
					status = "";
					break;
				case "Delayed":
				case "Delayed Start":
				case "Suspended":
					scoreDetails = "<em>" + ($x(xmlResponse,"game","status",iGame) == "Suspended" ? "Susp" : "Delayed") + "</em>";
					status = "";
					break;
				case "Preview":
				case "Pre-Game":
					scoreDetails = $x(xmlResponse,"game","time",iGame).match(/Gm/) ? $x(xmlResponse,"game","time",iGame).replace(/Gm\s*([0-9])/,"<em>Game $1</em>") : this.timeString(gameTime);
					link = null;
					status = "P";
					break;
				case "Warmup":
					scoreDetails = "<em>Warmup</em>";
					status = "P";
					break;
				case "Postponed":
				case "Cancelled":
					scoreDetails = "<em>" + $x(xmlResponse,"game","status",iGame) + "</em>";
					status = "PP";
					break;
				// the following is not supposed to happen but let's be safe…
				default:
					scoreDetails = "<em>" + WC_.sanitizeString($x(xmlResponse,"game","status",iGame).replace(/ /g,"&nbsp;")) + "</em>";
					status = "";
			}
			var hasFav = null;
			if (SF_.prefs.currentLeague != "MLB" && SF_.prefs.favoriteTeam >= 0)
			// we have duplicate team codes for minor leagues so figure out whether the current game includes out favorite team here and pass it on
				hasFav = $x(xmlResponse,"game","away_team_id",iGame) == SF_.teams[SF_.prefs.currentLeague][SF_.prefs.favoriteTeam].imgName || $x(xmlResponse,"game","home_team_id",iGame) == SF_.teams[SF_.prefs.currentLeague][SF_.prefs.favoriteTeam].imgName;
			this.dates[0].games.push({
				gameID: gameID,
				status: status,
				link: link,
				gameTime: gameTime,
				scoreDetails: scoreDetails,
				awayTeam: $x(xmlResponse,"game","away_name_abbrev",iGame) || $x(xmlResponse,"game","away_team_code",iGame).toUpperCase(),
				awayTeamDetails: WC_.sanitizeString($x(xmlResponse,"game","away_team_city",iGame) || ""),
				awayTeamClass: "",
				awayScore: parseInt($x(xmlResponse,"game","away_team_runs",iGame) || 0, 10),
				homeTeam: $x(xmlResponse,"game","home_name_abbrev",iGame) || $x(xmlResponse,"game","home_team_code",iGame).toUpperCase(),
				homeTeamDetails: WC_.sanitizeString($x(xmlResponse,"game","home_team_city",iGame) || ""),
				homeTeamClass: "",
				homeScore: parseInt($x(xmlResponse,"game","home_team_runs",iGame) || 0, 10),
				gameDetails: gameDetails,
				hasFav: hasFav
			});
		}
	}
	this.draw();
}

SF_._scoreBoard.prototype._MLB_buildScoreDetails = function(gameStatus, inningNum, topInning, numOuts, runner1b, runner2b, runner3b)
{
	var statusText = "";
	if (gameStatus == "F")
		statusText = "F" + ((inningNum == "") || (parseInt(inningNum,10) == 9) ? "" : "/" + parseInt(inningNum,10)) 
	else if (gameStatus == "I")
	{
		if (numOuts != "3" )
		{
			statusText = "<span id='sbBaseDisplay'>";
			statusText += "<span class='sb3' style='margin-left:" + (runner3b ? "-1px" : "") + "'>" + (runner3b ? "◆" : "◇") + "</span>";
			statusText += "<span class='sb2'>" + (runner2b ? "◆" : "◇") + "</span>";
			statusText += "<span class='sb1' style='margin-left:" + (runner1b ? "-1px" : "") + "'>" + (runner1b ? "◆" : "◇") + "</span>";
			statusText += "</span>";
		}
		statusText += (numOuts == "3" ? "" : "<span class='TopBottom'>") + (topInning ? (numOuts == "3" ? "Mid " : "▲") : (numOuts == "3" ? "End " : "▼")) + (numOuts == "3" ? "" : "</span>") + parseInt(inningNum,10);
	}
	return statusText;
}

SF_._scoreBoard.prototype._MLB_getDateString = function(dayOffset)
{
	// make sure we always return the date according to the Eastern timezone (return the previous date until 6AM ET to make sure we always display the latest scoreboard while games might be going on - otherwise the default scoreboard display would almost always show the next day's schedule in Japan)
	var theDate = new Date();
	theDate = new Date(theDate.valueOf() + ((dayOffset || 0) * 86400000) - (this.isDST(new Date(theDate.valueOf() + ((dayOffset || 0) * 86400000))) ? 36000000 : 39600000) + (theDate.getTimezoneOffset() * 60000));
	return "year_" + theDate.getFullYear() + "/month_" + WC_.twoDigNum(theDate.getMonth() + 1) + "/day_" + WC_.twoDigNum(theDate.getDate());
}

SF_._scoreBoard.prototype._NBA_getDateString = function()
{
	var theDate = new Date();
	theDate = new Date(theDate.valueOf() - (this.isDST(new Date(theDate.valueOf())) ? 36000000 : 39600000) + (theDate.getTimezoneOffset() * 60000));
	return theDate.getFullYear() + WC_.twoDigNum(theDate.getMonth() + 1) + WC_.twoDigNum(theDate.getDate());
}

// overwrite the default showGameDetails() function since we are loading game data on the fly
SF_._scoreBoard.prototype.showGameDetails_MLB = function(iGame)
{
	var GameID = this.dates[0].games[parseInt(iGame.split("_")[1],10)].gameID || null;
	if (GameID === null) return;
	var _self = this;
	if (!SF_.prefs.showGameDetails) return;
	if ($s("gameDetails").visibility == "visible" && GameID == SF_.currentPopup) return;
	if ($s("ReloadSpinner").visibility == "visible") return;
	SF_.closePopup();
	WC_.stopSpinner("ReloadSpinner");
	if (this.popupTimer != null)
		clearTimeout(this.popupTimer);
	// close current game popup, remove old highlight from scoreboard and highlight the game we will be loading the popup for
	$("mainContent").innerHTML = $("mainContent").innerHTML.replace(/ selected/g,"").replace(new RegExp("(game_" + iGame + ")","g"),"$1 selected");	
	WC_.refreshView();
	SF_.currentPopup = GameID;
	if (this.xmlRequest)
	{
		this.xmlRequest.abort();
		this.xmlRequest = null;
	}
	if (this.xmlPlaysRequest)
	{
		this.xmlPlaysRequest.abort();
		this.xmlPlaysRequest = null;
	}
	this.xmlRequest = new XMLHttpRequest();
	this.xmlRequest.onload = function() {_self._MLB_drawGameDetails(iGame);}
	this.xmlRequest.open("GET",this.scoreBoardBaseLink() + this.scoreBoardLink.replace(/miniscoreboard.xml/,"gid_" + GameID + (this.dates[0].games[parseInt(iGame.split("_")[1],10)].status == "P" ? "/linescore.xml" : "/miniscoreboard.xml")));
	this.xmlRequest.setRequestHeader("Cache-Control", "no-cache");
	this.xmlRequest.send(null);
	if (!this.dayOffset)
		this.scoreBoardLink = null;
}

SF_._scoreBoard.prototype._MLB_drawGameDetails = function(iGame)
{
	var gameInfo = this.xmlRequest.responseXML;
	var _self = this;
	this.xmlRequest = null;
	if (!gameInfo)
	{
		SF_.currentPopup = "";
		return;
	}
	iGame = parseInt(iGame.split("_")[1],10);
	var theGame = this.dates[0].games[iGame];
	$s("gameDetails").height = "";
	$s("gameDetails").width = SF_.prefs.useLargeFonts ? "187px" : "156px";
	$("gameDetails").innerHTML = "<div id='base_1'>◇</div><div id='base_2'>◇</div><div id='base_3'>◇</div><div id='base_home'>◆</div><div id='InOut'></div><div id='playSpinner'></div><div id='scoreDetails'></div>";
	var pitcherStats = "";
	if ($x(gameInfo,"game_status","status") in {"Final":'',"Game Over":'',"Completed Early":''})
	// game finished
	{
		$s("base_1").visibility = "hidden";
		$s("base_2").visibility = "hidden";
		$s("base_3").visibility = "hidden";
		$s("base_home").visibility = "hidden";
		$("InOut").innerHTML = "";
		$s("scoreDetails").top = "2px";
		if ($x(gameInfo,"post_game") && $x(gameInfo,"winning_pitcher","first") != "null")
		{
			pitcherStats = "<div class='pitcherStats'>W: "
				+ $x(gameInfo,"winning_pitcher","first")[0] + ". " 
				+ WC_.sanitizeString($x(gameInfo,"winning_pitcher","last")) + " ("
				+ parseInt($x(gameInfo,"winning_pitcher","wins"),10) + "-"
				+ parseInt($x(gameInfo,"winning_pitcher","losses"),10) + ", "
				+ WC_.sanitizeString($x(gameInfo,"winning_pitcher","era")) + ")<br />" +
				" L: "
				+ $x(gameInfo,"losing_pitcher","first")[0] + ". " 
				+ WC_.sanitizeString($x(gameInfo,"losing_pitcher","last")) + " ("
				+ parseInt($x(gameInfo,"losing_pitcher","wins"),10) + "-"
				+ parseInt($x(gameInfo,"losing_pitcher","losses"),10) + ", "
				+ WC_.sanitizeString($x(gameInfo,"losing_pitcher","era")) + ")<br />";
			if ($x(gameInfo,"save_pitcher"))
			{
				pitcherStats += " S: "
					+ $x(gameInfo,"save_pitcher","first")[0] + ". " 
					+ WC_.sanitizeString($x(gameInfo,"save_pitcher","last")) + " ("
					+ parseInt($x(gameInfo,"save_pitcher","saves"),10) + ")";
			}
			pitcherStats += "</div>";
		}
		// update the main scoreboard display (in case the game just finished)
		this.getScoreBoardCell(iGame, parseInt($x(gameInfo,"r","away"),10) > parseInt($x(gameInfo,"r","home"),10) ? 0 : 1).innerHTML = "<span class='w'>" + this.getScoreBoardCell(iGame, parseInt($x(gameInfo,"r","away"),10) > parseInt($x(gameInfo,"r","home"),10) ? 0 : 1).innerText + "</span>";
		theGame.awayScore = parseInt($x(gameInfo,"r","away"),10);
		this.getScoreBoardCell(iGame, 2).innerHTML = theGame.awayScore;
		theGame.homeScore = parseInt($x(gameInfo,"r","home"),10);
		this.getScoreBoardCell(iGame, 3).innerHTML = theGame.homeScore;
		theGame.scoreDetails = this._MLB_buildScoreDetails("F",$x(gameInfo,"game_status","inning"));
		theGame.status = "F";
		this.getScoreBoardCell(iGame, 4).innerHTML = theGame.scoreDetails;
		this.currentGameStats[$x(gameInfo,"game","away_name_abbrev") + "@" + $x(gameInfo,"game","home_name_abbrev") + ($x(gameInfo,"game","id")[$x(gameInfo,"game","id").length-1] == "2" ? "_" : "")] = [theGame.awayScore,theGame.homeScore,"F"];
	}
	else if ($x(gameInfo,"home_probable_pitcher") || $x(gameInfo,"game","status") in {"Pre-Game":'',"Warmup":''})
	// game not yet started
	{
		$s("base_1").visibility = "hidden";
		$s("base_2").visibility = "hidden";
		$s("base_3").visibility = "hidden";
		$s("base_home").visibility = "hidden";
		$("InOut").innerHTML = "";
		$s("scoreDetails").top = "4px";
		$("scoreDetails").innerHTML = "<div class='pitcherInfo'>" + WC_.sanitizeString($x(gameInfo,"game","venue")) + "<br />" +
			WC_.sanitizeString($x(gameInfo,"game","away_team_name")) + ($x(gameInfo,"game","away_win") != null ? " (" + parseInt($x(gameInfo,"game","away_win"),10) + "&#8209;" + parseInt($x(gameInfo,"game","away_loss"),10) + ")" : "") + " vs. " +
			WC_.sanitizeString($x(gameInfo,"game","home_team_name")) + ($x(gameInfo,"game","home_win") != null ? " (" + parseInt($x(gameInfo,"game","home_win"),10) + "&#8209;" + parseInt($x(gameInfo,"game","home_loss"),10) + ")" : "") +
			($x(gameInfo,"game","tv_station") ? "<br />TV: " + WC_.sanitizeString($x(gameInfo,"game","tv_station")) : "") + 
			"</div><div class='pitcherStats'>" + ($x(gameInfo,"game","status") in {"Pre-Game":'',"Warmup":''} ? "Starting" : "Probable") + " pitchers:<br />"
			+ WC_.sanitizeString($x(gameInfo,"game","away_name_abbrev")) +": "
			+ ($x(gameInfo,"away_probable_pitcher","first_name") == "" ? "unknown" :
				$x(gameInfo,"away_probable_pitcher","first_name")[0] + ". "
			+ WC_.sanitizeString($x(gameInfo,"away_probable_pitcher","last_name")) + " ("
			+ parseInt($x(gameInfo,"away_probable_pitcher","wins"),10) + "-"
			+ parseInt($x(gameInfo,"away_probable_pitcher","losses"),10) + ", "
			+ WC_.sanitizeString($x(gameInfo,"away_probable_pitcher","era")) + ")" ) + "<br />"
			+ WC_.sanitizeString($x(gameInfo,"game","home_name_abbrev")) + ": "
			+ ($x(gameInfo,"home_probable_pitcher","first_name") == "" ? "unknown" : 
				$x(gameInfo,"home_probable_pitcher","first_name")[0] + ". "
			+ WC_.sanitizeString($x(gameInfo,"home_probable_pitcher","last_name")) + " ("
			+ parseInt($x(gameInfo,"home_probable_pitcher","wins"),10) + "-"
			+ parseInt($x(gameInfo,"home_probable_pitcher","losses"),10) + ", "
			+ WC_.sanitizeString($x(gameInfo,"home_probable_pitcher","era")) + ")" ) + "</div>";
		$s("gameDetails").right = (iGame % 2 != 0) ? "" : "11px";	// 11px needed for the shadow (offset + blur)
		$s("gameDetails").left = (iGame % 2 != 0) ? "11px" : "";		// …so we make this symmetrical
		$s("gameDetails").height = ($("scoreDetails").scrollHeight + 8) + "px";
		$s("gameDetails").width = ($("scoreDetails").scrollWidth + 10) + "px";
		$s("gameDetails").opacity = 0;
		if (SF_.fadeAnimation) SF_.fadeAnimation.stop();
		SF_.fadeAnimation = new AppleAnimator(500, 13, 0, 1, SF_.fadePopup);
		SF_.fadeAnimation.oncomplete = WC_.refreshView;
		SF_.fadeAnimation.start();
		$s("gameDetails").visibility = "visible";
		setTimeout("$('gameDetails').onmouseover = function() {SF_.closePopup();}",100);
		this.popupTimer = setTimeout(function(){SF_.closePopup(_self)},10000)
		return;
	}
	else
	// game currently ongoing
	{
		$s("base_1").visibility = $s("base_2").visibility = $s("base_3").visibility = $s("base_home").visibility = "";
		$s("base_1").marginTop = $s("base_2").marginTop = $s("base_3").marginTop = "";
		$s("InOut").left = "";
		$s("scoreDetails").top = "3.5em";
		if (!($x(gameInfo,"game_status","status") in {"Suspended":'', "Delayed":'', "Delayed Start":'',"Postponed":''})
			&& parseInt(this.getScoreBoardCell(iGame, 2).innerHTML,10) == this.getScoreBoardCell(iGame, 2).innerHTML)
		{
			// update number of runs on main scoreboard display
			theGame.awayScore = parseInt($x(gameInfo,"r","away"),10);
			this.getScoreBoardCell(iGame, 2).innerHTML = theGame.awayScore;
			theGame.homeScore = parseInt($x(gameInfo,"r","home"),10);
			this.getScoreBoardCell(iGame, 3).innerHTML = theGame.homeScore;
			this.currentGameStats[$x(gameInfo,"game","away_name_abbrev") + "@" + $x(gameInfo,"game","home_name_abbrev") + ($x(gameInfo,"game","id")[$x(gameInfo,"game","id").length-1] == "2" ? "_" : "")] = [theGame.awayScore,theGame.homeScore,""];
		}
		if ($x(gameInfo,"game_status","o") == "3")
		{
			$("InOut").innerHTML = ($x(gameInfo,"game_status","top_inning") == "Y" ? "Middle" : "End") + " of "
				+ WC_.ordinalNumber($x(gameInfo,"game_status","inning")) + " Inning";
			if (!($x(gameInfo,"game_status","status") in {"Suspended":'', "Delayed":'',"Postponed":''})
				&& parseInt(this.getScoreBoardCell(iGame, 2).innerHTML,10) == this.getScoreBoardCell(iGame, 2).innerHTML)
			{
				$s("InOut").top = "8px";
				// update game info on scoreboard
				theGame.scoreDetails = this._MLB_buildScoreDetails("I",$x(gameInfo,"game_status","inning"),$x(gameInfo,"game_status","top_inning") == "Y","3");
				this.getScoreBoardCell(iGame, 4).innerHTML = theGame.scoreDetails;
			}
			else
			{
				$("InOut").innerHTML += "<br /><span id='playerDetails' class='batter'>"
					+ WC_.sanitizeString($x(gameInfo,"game_status","status")) + "<br />"
					+ (WC_.sanitizeString($x(gameInfo,"game_status","delay_reason") || "")) + "</span>";
				$s("InOut").top = "";
			}
		}
		else
		{
			WC_.animateSpinner("playSpinner");
			$("InOut").innerHTML = "";
			$s("InOut").top = "";
			this.xmlPlaysRequest = new XMLHttpRequest();
			this.xmlPlaysRequest.onload = function() {_self._MLB_updateCurrentGameStatus(iGame);}
			this.xmlPlaysRequest.open("GET",this.scoreBoardBaseLink() + this.scoreBoardLink.replace(/miniscoreboard.xml/,"gid_" + theGame.gameID + "/plays.xml"));
			this.xmlPlaysRequest.setRequestHeader("Cache-Control","no-cache");
			this.xmlPlaysRequest.send(null);
			if (!this.dayOffset)
				this.scoreBoardLink = null;
		}
	}
	$s("InOut").width = $s("gameDetails").width = "";
	if (SF_.prefs.useLargeFonts)
	{
		$s("gameDetails").width = (1.2 * $("gameDetails").offsetWidth) + "px";
		$s("InOut").width = (1.2 * $("InOut").offsetWidth) + "px";
	}
	else
		$s("InOut").width = "";	
	var inningRow = "";
	var awayRow = "";
	var homeRow = "";
	var inningRow2 = "";
	var awayRow2 = "";
	var homeRow2 = "";
	var currentInning;
	var currentAwayRuns;
	var currentHomeRuns;
	var inning;
	for (inning = 0, lastInning = $x(gameInfo,"inning").length || 0; inning < lastInning; inning++)
	{
		currentInning = "<td>" + (inning+1) + "</td>";
		currentAwayRuns = "<td>" + ($x(gameInfo,"inning","away",inning) ? ($x(gameInfo,"inning","away",inning) == "0" ? "<span class='zero'>" : "") + parseInt($x(gameInfo,"inning","away",inning),10) : "&nbsp;") + "</td>";
		if (($x(gameInfo,"game_status","status_ind")[0] in {"F":'',"O":''})
				&& !$x(gameInfo,"inning","home",inning))
			currentHomeRuns = "<td class='zero'>X</td>";
		else
			currentHomeRuns = "<td>" + ($x(gameInfo,"inning","home",inning) ? ($x(gameInfo,"inning","home",inning) == "0" ? "<span class='zero'>" : "") + parseInt($x(gameInfo,"inning","home",inning),10) : "&nbsp;") + "</td>";
		// split extra innings into a second line so the text doesn't extend past the popup
		if (inning > 8)
		{
			if (inning > 9 && inning % 9 == 0)
			{
				inningRow2 += "</tr><tr class='odd'>" + awayRow2 + "</tr><tr>" + homeRow2 + "</tr><tr class='header2'>";
				awayRow2 = "";
				homeRow2 = "";
			}
			inningRow2 += currentInning;
			awayRow2 += currentAwayRuns;
			homeRow2 += currentHomeRuns;
		}
		else
		{
			inningRow += currentInning;
			awayRow += currentAwayRuns;
			homeRow += currentHomeRuns;
		}
	}
	// make sure we always display at least 9 innings
	for (var i = inning; i < 9; i++)
	{
		inningRow += "<td>" + (i+1) + "</td>";
		awayRow += "<td class='zero'>" + ($x(gameInfo,"game_status","status_ind")[0] in {"F":'',"O":''} ? "X" : "") + "</td>";
		homeRow += "<td class='zero'>" + ($x(gameInfo,"game_status","status_ind")[0] in {"F":'',"O":''} ? "X" : "") + "</td>";
	}
	inningRow += "<td class='summary'></td><td class='summary'>R</td><td>H</td><td>E</td>";
	awayRow += "<td class='summary'></td><td class='summary'>" + parseInt($x(gameInfo,"r","away"),10)
		+ "</td><td>" + parseInt($x(gameInfo,"h","away"),10)
		+ "</td><td>" + parseInt($x(gameInfo,"e","away"),10) + "</td>";
	homeRow += "<td class='summary'></td><td class='summary'>" + parseInt($x(gameInfo,"r","home"),10)
		+ "</td><td>" + parseInt($x(gameInfo,"h","home"),10)
		+ "</td><td>" + parseInt($x(gameInfo,"e","home"),10) + "</td>";
	
	$("scoreDetails").innerHTML = "<table><tr class='header'>" + inningRow + "</tr><tr class='odd'>" + awayRow + "</tr><tr>" + homeRow + (inningRow2 != "" ? ("<tr class='header2'>" + inningRow2 + "</tr><tr class='odd'>" + awayRow2 + "</tr><tr>" + homeRow2) : "") + "</tr></table>" + pitcherStats;
	$s("gameDetails").right = (iGame % 2 != 0) ? "" : "11px";
	$s("gameDetails").left = (iGame % 2 != 0) ? "11px" : "";
	$s("gameDetails").height = ($("scoreDetails").offsetHeight + ($s("base_1").visibility != "hidden" ? (SF_.prefs.useLargeFonts ? 51 : 43) : 5)) + "px";
	$s("gameDetails").width = ($("scoreDetails").scrollWidth + 10) + "px";
	$s("gameDetails").opacity = 0;
	if (SF_.fadeAnimation) SF_.fadeAnimation.stop();
	SF_.fadeAnimation = new AppleAnimator(500, 13, 0, 1, SF_.fadePopup);
	SF_.fadeAnimation.oncomplete = WC_.refreshView;
	SF_.fadeAnimation.start();
	$s("gameDetails").visibility = "visible";
	setTimeout("$('gameDetails').onmouseover = function() {SF_.closePopup();}",100);
	this.popupTimer = setTimeout(function(){SF_.closePopup(_self)},10000)
}

SF_._scoreBoard.prototype._MLB_updateCurrentGameStatus = function(iGame)
{
	var gameInfo = this.xmlPlaysRequest.responseXML;
	this.xmlPlaysRequest = null;
	if (gameInfo && $("InOut"))
	{
		if ($x(gameInfo,"game","o") == "3")
		{
			$("InOut").innerHTML = ($x(gameInfo,"game","top_inning") == "T" ? "Middle" : "End") + " of "
				+ WC_.ordinalNumber($x(gameInfo,"game","inning")) + " Inning";
			$s("InOut").top = "8px";
			// update game info on scoreboard
			if (parseInt(this.getScoreBoardCell(iGame, 2).innerHTML,10) == this.getScoreBoardCell(iGame, 2).innerHTML)
			{
				this.dates[0].games[iGame].scoreDetails = this._MLB_buildScoreDetails("I",$x(gameInfo,"game","inning"),$x(gameInfo,"game","top_inning") == "T","3");
				this.getScoreBoardCell(iGame, 4).innerHTML = this.dates[0].games[iGame].scoreDetails;
			}
			WC_.stopSpinner("playSpinner");
			return;
		}
		var batterNote = "";
		var runner1b = false;
		var runner2b = false;
		var runner3b = false;
		var useDeckBatter = $x(gameInfo,"players")[0].getElementsByTagName("batter")[0].getAttribute("pid") == $x(gameInfo,"atbat","player") && $x(gameInfo,"atbat")[0].childNodes.length > 1;
		for (var i = 0, len = $x(gameInfo,"field")[0].getElementsByTagName("offense")[0].childNodes.length; i < len; i++)
		{
			if ($x(gameInfo,"field")[0].getElementsByTagName("offense")[0].childNodes[i].tagName == "man")
			{
				var theBase = $x(gameInfo,"field")[0].getElementsByTagName("offense")[0].childNodes[i].getAttribute("bnum").replace(/.*?([1-4]).*/,"$1");
				if (theBase != "4")
				{
					$("base_" + theBase).innerHTML = "◆";
					$s("base_" + theBase).marginTop = "-1px";
					switch (theBase)
					{
						case "1":
							runner1b = true;
							break;
						case "2":
							runner2b = true;
							break;
						case "3":
							runner3b = true;
							break;
					}
				}
				else if (theBase == "4" && !useDeckBatter)
					batterNote = WC_.sanitizeString($x(gameInfo,"field")[0].getElementsByTagName("offense")[0].childNodes[i].getAttribute("note"));
			}
		}
		$s("InOut").top = "";
		if ($x(gameInfo,"game","status") in {"Suspended":'',"Delayed":'',"Postponed":''})
			$("InOut").innerHTML = "<span class='TopBottom'>"
				+ ($x(gameInfo,"game","top_inning") == "T" ? "▲" : "▼") + "</span>"
				+ parseInt($x(gameInfo,"game","inning"),10) + ", "
				+ parseInt($x(gameInfo,"game","o"),10) + " Out"
				+ ($x(gameInfo,"game","o") != "1" ? "s" : "")
				+ "<br /><span id='playerDetails' class='batter'>"
				+ WC_.sanitizeString($x(gameInfo,"game","status")) + "<br />"
				+ WC_.sanitizeString($x(gameInfo,"game","reason") || "") + "</span>";
		else if ($x(gameInfo,"game","status") == "Delayed Start")
		{
			$("InOut").innerHTML = "<span id='playerDetails' class='batter'>"
				+ WC_.sanitizeString($x(gameInfo,"game","status")) + "<br />"
				+ WC_.sanitizeString($x(gameInfo,"game","reason") || "") + "</span>";
			$s("InOut").top = "8px";
		}
		else
		{
			$("InOut").innerHTML = "<span class='TopBottom'>"
				+ ($x(gameInfo,"game","top_inning") == "T" ? "▲" : "▼") + "</span>"
				+ parseInt($x(gameInfo,"game","inning"),10) + ", "
				+ (useDeckBatter ? "0-0" : WC_.sanitizeString($x(gameInfo,"game","b") + "-" + $x(gameInfo,"game","s"))) + ", "
				+ parseInt($x(gameInfo,"game","o"),10) + " Out"
				+ ($x(gameInfo,"game","o") != "1" ? "s" : "")
				+ "<br /><span id='playerDetails' class='batter'>"
				+ "P: " + WC_.sanitizeString($x(gameInfo,"players")[0].getElementsByTagName("pitcher")[0].getAttribute("boxname")) + " (" + parseInt($x(gameInfo,"players")[0].getElementsByTagName("pitcher")[0].getAttribute("pitches"),10) + ": " + parseInt($x(gameInfo,"players")[0].getElementsByTagName("pitcher")[0].getAttribute("strikes"),10) + "," + parseInt($x(gameInfo,"players")[0].getElementsByTagName("pitcher")[0].getAttribute("balls"),10) + ")<br />"
				+ "AB: "+ WC_.sanitizeString($x(gameInfo,"players")[0].getElementsByTagName(useDeckBatter ? "deck" : "batter")[0].getAttribute("boxname"))
				+ (batterNote != "" ? (" (" + WC_.sanitizeString(batterNote.replace(/-for-/,"-")) + ")") : "");
			// if we have a special game action (coaching visit to mount, pitcher/batter change, ...) show it instead of current pitcher/batter
			if ($x(gameInfo,"action","des"))
				$("playerDetails").innerHTML = WC_.sanitizeString($x(gameInfo,"action","des"));
			$s("scoreDetails").top = "3.5em";
			var heightAdjustment = 0;
			if ((heightAdjustment = $("InOut").offsetHeight - (SF_.prefs.useLargeFonts ? 46 : 38)) > 0)
			{
				$s("scoreDetails").top = ($("scoreDetails").offsetTop + heightAdjustment) + "px";
				$s("gameDetails").height = (parseInt($s("gameDetails").height,10) + heightAdjustment + 2) + "px";
				WC_.refreshView();
			}
			// update game info on scoreboard and scoreboard var (only if the game was already in progress when the popup opened in order not to mess up the table layout)
			if (parseInt(this.getScoreBoardCell(iGame, 2).innerHTML,10) == this.getScoreBoardCell(iGame, 2).innerHTML)
			{
				this.dates[0].games[iGame].scoreDetails = this._MLB_buildScoreDetails("I",$x(gameInfo,"game","inning"),$x(gameInfo,"game","top_inning") == "T",$x(gameInfo,"game","o"),runner1b,runner2b,runner3b);
				this.getScoreBoardCell(iGame, 4).innerHTML = this.dates[0].games[iGame].scoreDetails;
			}
		}
	}
	WC_.stopSpinner("playSpinner");
	setTimeout("$('gameDetails').onmouseover = function() {SF_.closePopup();}",100);
}

//
